@@ -44,6 +44,8 @@
       integer i,j,k,nopes
 !
       real*8 col(3,nopes),colmean(3),straight(36),ps(8,3),dd,xn(3)
+!
+!
 !     
 !     sides of the quadrilateral
 !
@@ -78,7 +80,7 @@
 !     determining the inhomogeneous terms
 !     
       do i=1,3
-         colmean(i)=0.0
+         colmean(i)=0.d0
       enddo
       do j=1,nopes
          k=(j-1)*4
