@@ -1,6 +1,6 @@
 !     
 !     CalculiX - A 3-dimensional finite element program
-!     Copyright (C) 1998-2022 Guido Dhondt
+!     Copyright (C) 1998-2023 Guido Dhondt
 !     
 !     This program is free software; you can redistribute it and/or
 !     modify it under the terms of the GNU General Public License as
@@ -64,13 +64,13 @@
      &     nfaces,ig,ifaceq(8,6),ifacet(6,4),ifacew(8,5),
      &     mscalmethod,icount,mortar
 !     
-      real*8 elas(21),wavespeed(*),rhcon(0:1,ntmat_,*)  ,
+      real*8 elas(21),wavespeed(*),rhcon(0:1,ntmat_,*),volfac,
      &     alcon(0:6,ntmat_,*),coords(3),orab(7,*),rho,alzero(*),
-     &     t0l,t1l,elconloc(21),eth(6),plicon(0:2*npmat_,ntmat_,*),
+     &     t0l,t1l,elconloc(ncmat_),eth(6),plicon(0:2*npmat_,ntmat_,*),
      &     plkcon(0:2*npmat_,ntmat_,*),plconloc(802),dtime,
-     &     xstiff(27,mi(1),*),elcon(0:ncmat_,ntmat_,*),
-     &     t0(*),t1(*),shp(4,26),vold(0:mi(2),*),tt,
-     &     e,un,wavspd,xi,et,ze,weight,co(3,*),xl(3,26),xsj,
+     &     xstiff(27,mi(1),*),elcon(0:ncmat_,ntmat_,*),aa,bb,cc,
+     &     t0(*),t1(*),shp(4,20),vold(0:mi(2),*),tt,
+     &     e,un,wavspd,xi,et,ze,weight,co(3,*),xl(3,20),xsj,
      &     xl2(3,9),xsj2(3),xs2(3,7),shp2(7,9),hmin,area,
      &     volume,dtvol,safefac,alpha,bet,gam,critom,damping,
      &     elemfac,quadfac,smscale(*),dtset   
@@ -101,6 +101,7 @@
 !     alpha method is not used for massless contact)
 !     
       if(mortar.ne.-1) then
+c        safefac=0.50d0
         safefac=0.80d0
       else
         safefac=0.80d0/1.3d0
@@ -116,12 +117,21 @@
 !     Calculation of Omega Critical
 !     Om_cr=dt*freq_max
 !     
-      critom=dsqrt(damping*damping*(1.d0+2.d0*alpha*(1.d0-gam))
-     &     *(1.d0+2.d0*alpha*(1.d0-gam))
-     &     +2.d0*(gam+2.d0*alpha*(gam-bet)) )
-      critom=0.98d0*(-damping*(1.d0+2.d0*alpha*(1.d0-gam))+critom)
-     &     /(gam+2.d0*alpha*(gam-bet)) !eq 25 miranda
-
+c      critom=dsqrt(damping*damping*(1.d0+2.d0*alpha*(1.d0-gam))
+c     &     *(1.d0+2.d0*alpha*(1.d0-gam))
+c     &     +2.d0*(gam+2.d0*alpha*(gam-bet)))
+c      critom=0.98d0*(-damping*(1.d0+2.d0*alpha*(1.d0-gam))+critom)
+c     &     /(gam+2.d0*alpha*(gam-bet)) !eq 25 miranda
+!
+!     formula (2.477) with +sign from Dhondt, Wiley(2004), the Finite      
+!        Element Method for Three-Dimensional Thermomechanical Applications.
+!     factor 0.98 in critom from miranda?
+!      
+      aa=1.d0-alpha*(1.d0+alpha*(2.d0+alpha))
+      bb=2.d0*damping*(1.d0+alpha*(1.d0+2.d0*alpha))
+      cc=-4.d0
+      critom=0.98d0*(-bb+dsqrt(bb*bb-aa*cc))/aa
+!     
       write(*,*)'Calculating Material Wave Speeds...'
       write(*,*)
 !     
@@ -136,6 +146,7 @@
 !     ** DO per element
       do nelem=1,ne0
         if(ipkon(nelem).lt.0) cycle
+c        write(*,*) 'calcstabletimeincvol ',nelem
 !     
         lakonl=lakon(nelem)
         imat=ielmat(1,nelem)
@@ -173,11 +184,13 @@
             nope=8
             nopes=4
             nfaces=6
-            elemfac=0.5d0
+            elemfac=0.625d0
+c            elemfac=0.5d0
           elseif(lakon(nelem)(4:4).eq.'8') then
             nope=8
             nopes=4
             nfaces=6
+            if(mortar.eq.-1) elemfac=0.9d0
           elseif(lakon(nelem)(4:5).eq.'10')then
             nope=10
             nopes=6
@@ -314,21 +327,21 @@
 !     
 !     single crystal
 !     
-            if(((elas(1).eq.elas(3)).and.(elas(1).eq.elas(6)).and.
-     &           (elas(3).eq.elas(6))).and.
-     &           ((elas(2).eq.elas(4)).and.(elas(2).eq.elas(5)).and.
-     &           (elas(4).eq.elas(5))).and.
-     &           ((elas(7).eq.elas(8)).and.(elas(7).eq.elas(9)).and.
-     &           (elas(8).eq.elas(9)))) then
-              wavspd=max(wavspd,dsqrt((1/3.d0)*(elas(1)+2.0*elas(2)+
-     &             4.0d0*elas(7))/rho))
-              wavspd=max(wavspd,dsqrt((1/2.d0)*
-     &             (elas(1)+elas(2)+2.0*elas(7))/rho))
-              wavspd=max(wavspd,dsqrt(elas(1)/rho))
-            else
+c            if(((elas(1).eq.elas(3)).and.(elas(1).eq.elas(6)).and.
+c     &           (elas(3).eq.elas(6))).and.
+c     &           ((elas(2).eq.elas(4)).and.(elas(2).eq.elas(5)).and.
+c     &           (elas(4).eq.elas(5))).and.
+c     &           ((elas(7).eq.elas(8)).and.(elas(7).eq.elas(9)).and.
+c     &           (elas(8).eq.elas(9)))) then
+c              wavspd=max(wavspd,dsqrt((1/3.d0)*(elas(1)+2.0*elas(2)+
+c     &             4.0d0*elas(7))/rho))
+c              wavspd=max(wavspd,dsqrt((1/2.d0)*
+c     &             (elas(1)+elas(2)+2.0*elas(7))/rho))
+c              wavspd=max(wavspd,dsqrt(elas(1)/rho))
+c            else
               iorth=1
-              call anisomaxwavspd(elas,rho,iorth,wavspd )
-            endif
+              call anisomaxwavspd(elas,rho,iorth,wavspd)
+c            endif
           elseif(mattyp.eq.3) then
             iorth=0
             call anisomaxwavspd(elas,rho,iorth,wavspd)
@@ -336,22 +349,31 @@
 !     
           wavespeed(imat)=wavspd
 !     
-!     ------------Critical time step calcualtion-----------------------
+!     ------------Critical time step calculation-----------------------
 !     
 !     Divides volume accordingly per geometry of element
 !     Carlo MT proposal
 !     if HEX
-          if((lakon(nelem)(4:5).eq.'20').or.
-     &         (lakon(nelem)(4:4).eq.'8')) then
-            volume=weight*xsj
-!     if TET
-          elseif((lakon(nelem)(4:5).eq.'10').or.
-     &           (lakon(nelem)(4:4).eq.'4')) then
-            volume=weight*xsj/3.d0
-!     if WEDGES
-          elseif ( (lakonl(4:5).eq.'15').or.
-     &           (lakonl(4:4).eq.'6'))then
-            volume=weight*xsj/2.d0
+c          if((lakon(nelem)(4:5).eq.'20').or.
+c     &         (lakon(nelem)(4:4).eq.'8')) then
+c            volume=weight*xsj
+c!     if TET
+c          elseif((lakon(nelem)(4:5).eq.'10').or.
+c     &           (lakon(nelem)(4:4).eq.'4')) then
+c            volume=weight*xsj/3.d0
+c!     if WEDGES
+c          elseif ( (lakonl(4:5).eq.'15').or.
+c     &           (lakonl(4:4).eq.'6'))then
+c            volume=weight*xsj/2.d0
+c     endif
+!
+!         volume=area*h*volfac
+!
+          volume=weight*xsj
+          volfac=1.d0
+          if((lakon(nelem)(4:5).eq.'10').or.
+     &         (lakon(nelem)(4:4).eq.'4')) then
+            volfac=3.d0
           endif
 !     
           hmin=1.d30
@@ -363,12 +385,14 @@
                 nopes=3
               else
                 nopes=4
+                volfac=2.d0
               endif
             elseif(lakon(nelem)(4:5).eq.'15')then
               if(ig.le.2)then
                 nopes=6
               else
                 nopes=8
+                volfac=2.d0
               endif
             endif
 !
@@ -415,13 +439,17 @@
             area=weight*dsqrt(xsj2(1)*xsj2(1)+xsj2(2)*xsj2(2)+
      &           xsj2(3)*xsj2(3))
 
-            hmin=min(hmin,(volume/area))
+            hmin=min(hmin,(volume*volfac/area))
 !     
           enddo
 !     ENDDO over sides
 !     
 !     scaling of element: time increment required by element
-!     
+!
+c          write(*,*) 'calcstabletimeincvol ',critom
+c          write(*,*) 'calcstabletimeincvol ',hmin
+c          write(*,*) 'calcstabletimeincvol ',elemfac
+c          write(*,*) 'calcstabletimeincvol ',wavspd
           smscale(nelem)=critom*hmin*elemfac/(2.d0*wavspd)
 !     
 !     smallest dtvol
@@ -439,8 +467,11 @@
 !     ------------Mass Scaling ----------------------------------------
 !     mscalmethod=1: selective mass scaling SMS
 !     not active for massless contact      
-!     
-      if((dtvol.lt.dtset/safefac).and.(mortar.ne.-1))then
+!
+c       write(*,*) 'calcstabletimeincvol ',dtvol
+c      write(*,*) 'calcstabletimeincvol ',dtset
+c      write(*,*) 'calcstabletimeincvol ',safefac
+      if((dtvol.lt.dtset/safefac))then
         dtset=dtset/safefac
         mscalmethod=1
 !     
@@ -471,7 +502,7 @@
           write(*,*) 'In total ',icount,'elements were scaled'
           write(*,*) 
           write(*,*) '*INFO in calcstabletimeincvol:'
-          write(*,*) '      scaled nodes are stored in file'
+          write(*,*) '      scaled elements are stored in file'
           write(*,*) '      ',fn(1:ilen+26)
           write(*,*) '      This file can be loaded into'
           write(*,*) '      an active cgx-session by typing'
