@@ -1,5 +1,5 @@
 /*     CalculiX - A 3-dimensional finite element program                 */
-/*              Copyright (C) 1998-2022 Guido Dhondt                     */
+/*              Copyright (C) 1998-2023 Guido Dhondt                     */
 
 /*     This program is free software; you can redistribute it and/or     */
 /*     modify it under the terms of the GNU General Public License as    */
@@ -64,14 +64,14 @@ int main(int argc,char *argv[])
     *irandomtype=NULL,irobustdesign[3],*iparentel=NULL,ifreebody,
     *ipobody=NULL,inewton=0,*iprfn=NULL,*konrfn=NULL;
      
-  ITG nk,ne,nboun,nmpc,nforc,nload,nprint,nset,nalset,nentries=18,
+  ITG nk,ne,nboun,nmpc,nforc,nload,nprint,nset,nalset,nentries=19,
     nmethod,neq[3],i,mpcfree,mei[4]={0,0,0,0},j,nzl,nam,nbounold,
     nforcold,nloadold,nbody,nbody_,nbodyold,network,nheading_,
     k,nzs[3],nmpc_,nload_,nforc_,istep,istat,nboun_,nintpoint,
     iperturb[2],nmat,ntmat_,norien,ithermal[2]={0,0},nmpcold,
-    iprestr,kode,isolver,nslavs,nkon_,ne0,nkon0,mortar,
+    iprestr,kode,isolver,nslavs,nkon_,ne1,nkon0,mortar,
     jout[2],nlabel,nkon,idrct,jmax[2],iexpl,nevtot,ifacecount,
-    iplas,npmat_,mi[3],ntrans,mpcend,namtot_,iumat,iheading,
+    iplas,npmat_,mi[3],ntrans,mpcend,namtot_,iheading,
     icascade,maxlenmpc,mpcinfo[4],ne1d,ne2d,infree[4],
     callfrommain,nflow,jin=0,irstrt[2],nener,jrstrt,nenerold,
     nline,*ipoinp=NULL,*inp=NULL,ntie,ntie_,mcs,nprop_,
@@ -98,7 +98,7 @@ int main(int argc,char *argv[])
     *cs=NULL,*tietol=NULL,*fmpc=NULL,*prop=NULL,*t0g=NULL,*t1g=NULL,
     *xbody=NULL,*xbodyold=NULL,*coefmpcref=NULL,*dacon=NULL,*vel=NULL,
     *velo=NULL,*veloo=NULL,energy[5],*ratiorfn=NULL,*dgdxglob=NULL,
-    *g0=NULL,*xdesi=NULL,*coeffc=NULL,*edc=NULL;
+    *g0=NULL,*xdesi=NULL,*coeffc=NULL,*edc=NULL,*coini=NULL;
     
   double ctrl[57];
 
@@ -118,20 +118,24 @@ int main(int argc,char *argv[])
   else{
     for(i=1;i<argc;i++){
       if(strcmp1(argv[i],"-i")==0){
-	strcpy(jobnamec,argv[i+1]);strcpy1(jobnamef,argv[i+1],132);jin++;break;}
+	if(strlen(argv[i+1])>127){
+	  printf(" *ERROR in CalculiX: the number of characters in the name of the input deck (without .inp) exceeds 127 characters\n");
+	  FORTRAN(stop,());
+	}
+	strcpy2(jobnamec,argv[i+1],132);
+	strcpy1(jobnamef,argv[i+1],132);jin++;break;}
       if(strcmp1(argv[i],"-v")==0){
-	printf("\nThis is Version 2.20\n\n");
+	printf("\nThis is Version 2.21\n\n");
 	FORTRAN(stop,());
       }
     }
-    if(jin==0){strcpy(jobnamec,argv[1]);strcpy1(jobnamef,argv[1],132);}
-
-    /* next lines deactivated on March 18, 2020 */
-    
-    /*    for(i=1;i<argc;i++){
-      if(strcmp1(argv[i],"-o")==0){
-	strcpy(output,argv[i+1]);break;}
-	}*/
+    if(jin==0){
+      if(strlen(argv[1])>127){
+	printf(" *ERROR in CalculiX: the number of characters in the name of the input deck (without .inp) exceeds 127 characters\n");
+	FORTRAN(stop,());
+      }
+      strcpy2(jobnamec,argv[1],132);
+      strcpy1(jobnamef,argv[1],132);}
   }
 
   putenv("CCX_JOBNAME_GETJOBNAME=jobnamec");
@@ -145,12 +149,16 @@ int main(int argc,char *argv[])
   FORTRAN(openfile,(jobnamef));
 
   printf("\n************************************************************\n\n");
-  printf("CalculiX Version 2.20, Copyright(C) 1998-2022 Guido Dhondt\n");
+#ifdef INTSIZE64
+  printf("CalculiX Version 2.21 i8, Copyright(C) 1998-2023 Guido Dhondt\n");
+#else
+  printf("CalculiX Version 2.21, Copyright(C) 1998-2023 Guido Dhondt\n");
+#endif
   printf("CalculiX comes with ABSOLUTELY NO WARRANTY. This is free\n");
   printf("software, and you are welcome to redistribute it under\n");
   printf("certain conditions, see gpl.htm\n\n");
   printf("************************************************************\n\n");
-  printf("You are using an executable made on Sun Jul 31 18:08:37 CEST 2022\n");
+  printf("You are using an executable made on Sat Jul 29 10:52:01 CEST 2023\n");
   fflush(stdout);
 
   NNEW(ipoinp,ITG,2*nentries);
@@ -174,7 +182,7 @@ int main(int argc,char *argv[])
 	  &nbodyold,&network,&nheading_,&nmpc_,&nload_,&nforc_,&nboun_,
 	  &nintpoint,iperturb,&ntmat_,ithermal,&isolver,&nslavs,&nkon_,&mortar,
 	  jout,&nkon,&nevtot,&ifacecount,&iplas,&npmat_,mi,&mpcend,&namtot_,
-	  &iumat,&icascade,&ne1d,&ne2d,infree,&nflow,irstrt,&nener,&jrstrt,
+	  &icascade,&ne1d,&ne2d,infree,&nflow,irstrt,&nener,&jrstrt,
 	  &ntie_,&mcs,&nprop_,&nprop,&itpamp,&nevdamp_,&npt_,&iaxial,&inext,
 	  &icontact,&nobject,&nobject_,&iit,&mpcfreeref,&isens,&namtot,&nstam,
 	  &ndamp,&nef,&nk_,&ne_,&nalset_,&nmat_,&norien_,&nam_,
@@ -199,7 +207,6 @@ int main(int argc,char *argv[])
 		      &nforcold,&nloadold,&nbodyold,&mpcend,irobustdesign,
 		      &nfc_,&ndc_));
 
-  //  SFREE(set);
   SFREE(meminset);SFREE(rmeminset);mt=mi[1]+1;
   NNEW(heading,char,66*nheading_);
 
@@ -456,6 +463,7 @@ int main(int argc,char *argv[])
 	NNEW(xdesi,double,3*nk_);
 	NNEW(objectset,char,405*nobject_);
 	for(i=0;i<405*nobject_;i++){objectset[i]=' ';}
+	NNEW(coini,double,3*nk_);
       }
 
       /* temporary fields for cyclic symmetry calculations */
@@ -571,7 +579,7 @@ int main(int argc,char *argv[])
       if(ithermal[0]!=0) NNEW(t1old,double,nk_); 
       NNEW(sti,double,6*mi[0]*ne);
       NNEW(eme,double,6*mi[0]*ne);
-      if(nener==1)NNEW(ener,double,mi[0]*ne*2);
+      if(nener==1)NNEW(ener,double,2*mi[0]*ne);
       if(mcs>ntie_) RENEW(cs,double,17*mcs);
       if(mortar==1){
 	NNEW(pslavsurf,double,3*nintpoint);
@@ -585,7 +593,7 @@ int main(int argc,char *argv[])
 
     /* opening the eigenvalue file and checking for cyclic symmetry */
 
-    strcpy(fneig,jobnamec);
+    strcpy2(fneig,jobnamec,132);
     strcat(fneig,".eig");
     cyclicsymmetry=0;
     if((f1=fopen(fneig,"rb"))!=NULL){
@@ -600,7 +608,6 @@ int main(int argc,char *argv[])
 
     /* reading the input file */
 
-    //    if(istep==0)mortar=-2;
     FORTRAN(calinput,(co,&nk,kon,ipkon,lakon,&nkon,&ne,nodeboun,ndirboun,xboun,
 		      &nboun,ipompc,nodempc,coefmpc,&nmpc,&nmpc_,nodeforc,
 		      ndirforc,xforc,&nforc,&nforc_,nelemload,sideload,xload,
@@ -613,7 +620,7 @@ int main(int argc,char *argv[])
 		      timepar,xmodal,filab,jout,&nlabel,&idrct,jmax,&iexpl,
 		      alpha,iamboun,plicon,nplicon,plkcon,nplkcon,&iplas,
 		      &npmat_,mi,&nk_,trab,inotr,&ntrans,ikboun,ilboun,ikmpc,
-		      ilmpc,ics,dcs,&ncs_,&namtot_,cs,&nstate_,&ncmat_,&iumat,
+		      ilmpc,ics,dcs,&ncs_,&namtot_,cs,&nstate_,&ncmat_,
 		      &mcs,labmpc,iponor,xnor,knor,thickn,thicke,ikforc,ilforc,
 		      offset,iponoel,inoel,rig,infree,nshcon,shcon,cocon,
 		      ncocon,physcon,&nflow,ctrl,&maxlenmpc,&ne1d,&ne2d,&nener,
@@ -629,7 +636,7 @@ int main(int argc,char *argv[])
 		      &mpcfreeref,&maxlenmpcref,&memmpc_,&isens,&namtot,&nstam,
 		      dacon,vel,&nef,velo,veloo,ne2boun,itempuser,
 		      irobustdesign,irandomtype,randomval,&nfc,&nfc_,coeffc,
-		      ikdc,&ndc,&ndc_,edc));
+		      ikdc,&ndc,&ndc_,edc,coini));
     
     SFREE(idefforc);SFREE(idefload);SFREE(idefbody);
 
@@ -673,8 +680,6 @@ int main(int argc,char *argv[])
       calculix_registerExternalBehaviour(matname+80*i);
     }
 #endif /* CALCULIX_EXTERNAL_BEHAVIOURS_SUPPORT */
-  
-    //    if((istep==1)&&(mortar==-1)){mortar=0;}else{icontact=1;}
 
     nload0=nload;
 
@@ -683,12 +688,6 @@ int main(int argc,char *argv[])
       iheading=1;
     }
 
-    /*    if(nheading_>=0){
-      writeheading(jobnamec,heading,&nheading_);
-      SFREE(heading);
-      nheading_=-1;
-      }*/
-
     if((abs(nmethod)!=1)||(iperturb[0]<2))icascade=0;
 
     //    FORTRAN(writeboun,(nodeboun,ndirboun,xboun,typeboun,&nboun));
@@ -1019,10 +1018,11 @@ int main(int argc,char *argv[])
     /* energy */
 
     if((nener==1)&&(nenerold==0)){
-      NNEW(ener,double,mi[0]*ne*2);
+      NNEW(ener,double,2*mi[0]*ne);
       if((istep>1)&&(iperturb[0]>1)){
 	printf(" *ERROR in CalculiX: in nonlinear calculations\n");
-	printf("        energy output must be selected in the first step\n\n");
+	printf("        energy output requests, if any,\n");
+	printf("        must be specified in the first step\n\n");
 	FORTRAN(stop,());
       }
     }
@@ -1050,7 +1050,7 @@ int main(int argc,char *argv[])
     /* generate force convection elements */
 
     if(network>0){
-      ne0=ne;nkon0=nkon;nload1=nload;
+      ne1=ne;nkon0=nkon;nload1=nload;
       RENEW(ipkon,ITG,ne+nload);
       RENEW(ielmat,ITG,mi[2]*(ne+nload));
       for(i=mi[2]*ne;i<mi[2]*(ne+nload);i++)ielmat[i]=0;
@@ -1084,10 +1084,26 @@ int main(int argc,char *argv[])
 	RENEW(iamload,ITG,2*nload);
 	for(i=2*nload1;i<2*nload;i++)iamload[i]=0;
       }
-      if(nener==1)RENEW(ener,double,mi[0]*ne*2);
+      if(nener==1)RENEW(ener,double,2*mi[0]*ne);
+
+      /* moving the contact state variables forward by (ne-ne1) 
+	 element blocks (because of the advective elements) */
+      
+      if(mortar!=1){
+	RENEW(xstate,double,nstate_*mi[0]*(ne+nslavs));
+	for(i=nstate_*mi[0]*(ne+nslavs)-1;i>=nstate_*mi[0]*ne;i--){
+	  xstate[i]=xstate[i-nstate_*mi[0]*(ne-ne1)];
+	}
+      }else if(mortar==1){
+	RENEW(xstate,double,nstate_*mi[0]*(ne+nintpoint));
+	for(i=nstate_*mi[0]*(ne+nintpoint)-1;i>=nstate_*mi[0]*ne;i--){
+	  xstate[i]=xstate[i-nstate_*mi[0]*(ne-ne1)];
+	}
+      }
+      
       if(norien>0)RENEW(ielorien,ITG,mi[2]*ne);
       RENEW(ielmat,ITG,mi[2]*ne);
-      for(i=mi[2]*ne0;i<mi[2]*ne;i++)ielmat[i]=1;
+      for(i=mi[2]*ne1;i<mi[2]*ne;i++)ielmat[i]=1;
     }
 
     if(ntrans>0){
@@ -1162,7 +1178,7 @@ int main(int argc,char *argv[])
 		 nodempc,&nmpc,nactdof,icol,jq,&mast1,&irow,&isolver,neq,
 		 ikmpc,ilmpc,ipointer,nzs,&nmethodl,ithermal,
 		 ikboun,ilboun,iperturb,mi,&mortar,typeboun,labmpc,
-		 &iit,&icascade,&network,&iexpl);
+		 &iit,&icascade,&network,&iexpl,ielmat,matname);
       }
       else{neq[0]=1;neq[1]=1;neq[2]=1;}
     }
@@ -1176,19 +1192,19 @@ int main(int argc,char *argv[])
       mastructcs(&nk,kon,ipkon,lakon,&ne,nodeboun,ndirboun,&nboun,
 		 ipompc,nodempc,&nmpc,nactdof,icol,jq,&mast1,&irow,&isolver,
 		 neq,ikmpc,ilmpc,ipointer,nzs,&nmethodl,
-		 ics,cs,labmpc,&mcs,mi,&mortar);
+		 ics,cs,labmpc,&mcs,mi,&mortar,ielmat,matname);
     }
   
     SFREE(ipointer);SFREE(mast1);
     if((icascade==0)&&(nmethod<8))RENEW(irow,ITG,nzs[2]);
 
-    /* nmethod=1: static analysis   */
-    /* nmethod=2: frequency analysis  */
-    /* nmethod=3: buckling analysis */
-    /* nmethod=4: (linear or nonlinear) dynamic analysis */
-    /* nmethod=5: steady state dynamics analysis */
-    /* nmethod=6: Coriolis frequency calculation */
-    /* nmethod=7: flutter frequency calculation */
+    /* nmethod=1:  static analysis   */
+    /* nmethod=2:  frequency analysis  */
+    /* nmethod=3:  buckling analysis */
+    /* nmethod=4:  (linear or nonlinear) dynamic analysis */
+    /* nmethod=5:  steady state dynamics analysis */
+    /* nmethod=6:  Coriolis frequency calculation */
+    /* nmethod=7:  flutter frequency calculation */
     /* nmethod=8:  magnetostatics */
     /* nmethod=9:  magnetodynamics */
     /* nmethod=10: electromagnetic eigenvalue problems */
@@ -1232,7 +1248,7 @@ int main(int argc,char *argv[])
 		    &nbody,
 		    xbodyold,timepar,thicke,jobnamec,tieset,&ntie,&istep,&nmat,
 		    ielprop,prop,typeboun,&mortar,mpcinfo,tietol,ics,
-		    orname,itempuser,t0g,t1g);
+		    orname,itempuser,t0g,t1g,jmax);
 
 	  for(i=0;i<3;i++){nzsprevstep[i]=nzs[i];}
 
@@ -1257,7 +1273,7 @@ int main(int argc,char *argv[])
 		    xloadold,veold,accold,amname,amta,namta,&nam,iamforc,
 		    &iamload,iamt1,alpha,&iexpl,iamboun,plicon,nplicon,plkcon,
 		    nplkcon,&xstate,&npmat_,&istep,&ttime,matname,qaold,mi,
-		    &isolver,&ncmat_,&nstate_,&iumat,cs,&mcs,&nkon,&ener,
+		    &isolver,&ncmat_,&nstate_,cs,&mcs,&nkon,&ener,
 		    mpcinfo,output,shcon,nshcon,cocon,ncocon,physcon,&nflow,
 		    ctrl,set,&nset,istartset,iendset,ialset,&nprint,prlab,
 		    prset,&nener,ikforc,ilforc,trab,inotr,&ntrans,&fmpc,cbody,
@@ -1366,7 +1382,7 @@ int main(int argc,char *argv[])
 	       set,&nset,istartset,iendset,ialset,&nprint,prlab,
 	       prset,&nener,&isolver,trab,inotr,&ntrans,&ttime,fmpc,ipobody,
 	       ibody,xbody,&nbody,thicke,jobnamec,&nmat,ielprop,prop,
-	       orname,typeboun,t0g,t1g);
+	       orname,typeboun,t0g,t1g,&mcs,&istep);
 #else
       printf(" *ERROR in CalculiX: the ARPACK library is not linked\n\n");
       FORTRAN(stop,());
@@ -1492,7 +1508,7 @@ int main(int argc,char *argv[])
 		       &nam,iamforc,&iamload,iamt1,alpha,
 		       &iexpl,iamboun,plicon,nplicon,plkcon,nplkcon,
 		       &xstate,&npmat_,&istep,&ttime,matname,qaold,mi,
-		       &isolver,&ncmat_,&nstate_,&iumat,cs,&mcs,&nkon,&ener,
+		       &isolver,&ncmat_,&nstate_,cs,&mcs,&nkon,&ener,
 		       mpcinfo,output,
 		       shcon,nshcon,cocon,ncocon,physcon,&nflow,ctrl,
 		       &set,&nset,&istartset,&iendset,&ialset,&nprint,prlab,
@@ -1530,7 +1546,7 @@ int main(int argc,char *argv[])
 		   &nobject,&objectset,&istat,orname,nzsprevstep,&nlabel,
 		   physcon,
 		   jobnamef,iponor,knor,&ne2d,iponoel,inoel,&mpcend,dgdxglob,
-		   g0,&nodedesi,&ndesi,&nobjectstart,&xdesi);
+		   g0,&nodedesi,&ndesi,&nobjectstart,&xdesi,rig);
     
       }else{
         sensi_orien(co,&nk,&kon,&ipkon,&lakon,&ne,nodeboun,ndirboun,
@@ -1576,7 +1592,7 @@ int main(int argc,char *argv[])
 		   typeboun,&mortar,mpcinfo,tietol,ics,&nobject,
 		   &objectset,&istat,orname,nzsprevstep,&nlabel,physcon,
 		   jobnamef,iponor,knor,&ne2d,iponoel,inoel,&mpcend,
-		   irobustdesign,irandomtype,randomval);
+		   irobustdesign,irandomtype,randomval,rig);
     }
 
     else if(nmethod==15){
@@ -1599,7 +1615,8 @@ int main(int argc,char *argv[])
 			nodeboun,&nboun,ndirboun,ithermal,co,vold,mi,&ielmat,
 			ielprop,prop,&kode,&nmethod,filab,&nstate_,&istep,cs,
 			set,&nset,istartset,iendset,ialset,jobnamec,output,
-			&ntrans,inotr,trab,orname,xdesi);         
+			&ntrans,inotr,trab,orname,xdesi,timepar,coini,ikboun,
+			nactdof,&ne2d,&nkon);         
       
     }
 
@@ -1646,7 +1663,7 @@ int main(int argc,char *argv[])
 		    &nobject_,&objectset,&nmethod,iperturb,&irefineloop,
 		    &iparentel,&iprfn,&konrfn,&ratiorfn,&heading,
 		    &nodedesi,&dgdxglob,&g0,&nuel_,&xdesi,&nfc,&coeffc,
-		    &ikdc,&edc);
+		    &ikdc,&edc,&coini);
 
 	/* closing and reopening the output files */
 	
@@ -1659,7 +1676,7 @@ int main(int argc,char *argv[])
 		&nbodyold,&network,&nheading_,&nmpc_,&nload_,&nforc_,&nboun_,
 		&nintpoint,iperturb,&ntmat_,ithermal,&isolver,&nslavs,&nkon_,
 		&mortar,jout,&nkon,&nevtot,&ifacecount,&iplas,&npmat_,mi,
-		&mpcend,&namtot_,&iumat,&icascade,&ne1d,&ne2d,infree,&nflow,
+		&mpcend,&namtot_,&icascade,&ne1d,&ne2d,infree,&nflow,
 		irstrt,&nener,&jrstrt,&ntie_,&mcs,&nprop_,&nprop,&itpamp,
 		&nevdamp_,&npt_,&iaxial,&inext,&icontact,&nobject,&nobject_,
 		&iit,&mpcfreeref,&isens,&namtot,&nstam,&ndamp,&nef,
@@ -1686,7 +1703,6 @@ int main(int argc,char *argv[])
 			    &nbounold,&nforcold,&nloadold,&nbodyold,&mpcend,
 			    irobustdesign,&nfc_,&ndc_));
 
-	//	SFREE(set);
 	SFREE(meminset);SFREE(rmeminset);mt=mi[1]+1;
 	NNEW(heading,char,66*nheading_);
 
@@ -1763,18 +1779,33 @@ int main(int argc,char *argv[])
     /* removing the advective elements, if any */
 
     if(network>0){
-      ne=ne0;nkon=nkon0;
-      RENEW(ipkon,ITG,ne);
-      RENEW(lakon,char,8*ne);
-      RENEW(kon,ITG,nkon);
-      RENEW(sti,double,6*mi[0]*ne);
-      RENEW(eme,double,6*mi[0]*ne);
-      if(iprestr>0) RENEW(prestr,double,6*mi[0]*ne);
-      if(nprop>0) RENEW(ielprop,ITG,ne);
-      if((ne1d!=0)||(ne2d!=0)) RENEW(offset,double,2*ne);
-      if(nener==1)RENEW(ener,double,mi[0]*ne*2);
-      if(norien>0)RENEW(ielorien,ITG,mi[2]*ne);
-      RENEW(ielmat,ITG,mi[2]*ne);
+      RENEW(ipkon,ITG,ne1);
+      RENEW(lakon,char,8*ne1);
+      RENEW(kon,ITG,nkon0);
+      RENEW(sti,double,6*mi[0]*ne1);
+      RENEW(eme,double,6*mi[0]*ne1);
+      if(iprestr>0) RENEW(prestr,double,6*mi[0]*ne1);
+      if(nprop>0) RENEW(ielprop,ITG,ne1);
+      if((ne1d!=0)||(ne2d!=0)) RENEW(offset,double,2*ne1);
+      if(nener==1)RENEW(ener,double,2*mi[0]*ne1);
+
+      /* moving the contact state variables back by (ne-ne1) 
+	 element blocks */
+      
+      if(mortar!=1){
+	for(i=nstate_*mi[0]*ne1;i<nstate_*mi[0]*(ne1+nslavs);i++){
+	  xstate[i]=xstate[i+nstate_*mi[0]*(ne-ne1)];
+	}
+	RENEW(xstate,double,nstate_*mi[0]*(ne1+nslavs));
+      }else if(mortar==1){
+	for(i=nstate_*mi[0]*ne1;i<nstate_*mi[0]*(ne1+nintpoint);i++){
+	  xstate[i]=xstate[i+nstate_*mi[0]*(ne-ne1)];
+	}
+	RENEW(xstate,double,nstate_*mi[0]*(ne1+nintpoint));
+      }
+
+      if(norien>0)RENEW(ielorien,ITG,mi[2]*ne1);
+      RENEW(ielmat,ITG,mi[2]*ne1);
 
       /* reactivating the original load labels */
 
@@ -1784,6 +1815,7 @@ int main(int argc,char *argv[])
 	  strcpy1(&sideload[20*(iload-1)],"F",1);
 	}
       }
+      ne=ne1;nkon=nkon0;
 
     }
 
@@ -1827,7 +1859,7 @@ int main(int argc,char *argv[])
 
   FORTRAN(closefile,());
 
-  strcpy(fneig,jobnamec);
+  strcpy2(fneig,jobnamec,132);
   strcat(fneig,".frd");
   if((f1=fopen(fneig,"ab"))==NULL){
     printf(" *ERROR in frd: cannot open frd file for writing...");
@@ -1865,7 +1897,7 @@ int main(int argc,char *argv[])
 	      &nobject_,&objectset,&nmethod,iperturb,&irefineloop,
 	      &iparentel,&iprfn,&konrfn,&ratiorfn,&heading,
 	      &nodedesi,&dgdxglob,&g0,&nuel_,&xdesi,&nfc,&coeffc,
-	      &ikdc,&edc);
+	      &ikdc,&edc,&coini);
   
 #ifdef CALCULIX_MPI
   MPI_Finalize();
