@@ -1,6 +1,6 @@
 !
 !     CalculiX - A 3-dimensional finite element program
-!              Copyright (C) 1998-2022 Guido Dhondt
+!              Copyright (C) 1998-2023 Guido Dhondt
 !
 !     This program is free software; you can redistribute it and/or
 !     modify it under the terms of the GNU General Public License as
@@ -24,8 +24,6 @@
 !     input deck (e.g. only nodal variables are requested)
 !
       implicit none
-!
-      logical force
 !
       character*1 cflag
       character*8 lakon(*),lakonl
@@ -33,11 +31,11 @@
       integer ipkon(*),inum(*),kon(*),ne,indexe,nope,nfield,mi(*),
      &  nk,i,j,nelemload(2,*),nload,node,nboun,nlayer,nopeexp,
      &  nodeboun(*),ndirboun(*),ithermal(*),ielmat(mi(3),*),
-     &  ielprop(*)
+     &  ielprop(*),iforce
 !
       real*8 yn,co(3,*),vold(0:mi(2),*),prop(*)
 !
-      force=.false.
+      iforce=0
 !
       do i=1,nk
          inum(i)=0
@@ -125,7 +123,7 @@ c     Bernhardi end
       if((cflag.ne.' ').and.(cflag.ne.'E')) then
          nfield=0
          call map3dto1d2d(yn,ipkon,inum,kon,lakon,nfield,nk,ne,cflag,co,
-     &         vold,force,mi,ielprop,prop)
+     &         vold,iforce,mi,ielprop,prop)
       endif
 !
       return
