@@ -1,6 +1,6 @@
 !     
 !     CalculiX - A 3-dimensional finite element program
-!     Copyright (C) 1998-2022 Guido Dhondt
+!     Copyright (C) 1998-2023 Guido Dhondt
 !     
 !     This program is free software; you can redistribute it and/or
 !     modify it under the terms of the GNU General Public License as
@@ -26,15 +26,17 @@
       implicit none
 !     
       integer nnfront,i,j,k,j1,j2,istartfront(*),iendfront(*),ifront(*),
-     &     node,nodenext,nodelast,noderel,n,ier,iedge,iedgerel,ielem,
-     &     matz,nfront,ifrontrel(*),iedno(2,*),ibounedg(*),ieled(2,*),
+     &     node,nodenext,nodelast,noderel,ier,iedge,iedgerel,ielem,
+     &     nfront,ifrontrel(*),iedno(2,*),ibounedg(*),ieled(2,*),
      &     kontri(3,*),isubsurffront(*),istartcrackfro(*),ncrack,
-     &     iendcrackfro(*),nstep,m,n1,n2,n3
-!     
-      real*8 co(3,*),xt(3,*),xn(3,*),xa(3,*),dd,s(3,3),w(3),
-     &     fv1(3),fv2(3),cg(3),stress(6,nstep,*),xtj2m1(3),angle(*),
-     &     z(3,3),xn1(3),xn2(3),p12(3),p23(3)
+     &     iendcrackfro(*),nstep,n1,n2,n3
 !     
+      real*8 co(3,*),xt(3,*),xn(3,*),xa(3,*),dd,xnor(3),
+     &     stress(6,nstep,*),xtj2m1(3),angle(*),
+     &     xn1(3),xn2(3),p12(3),p23(3),det,pi
+!
+      pi=4.d0*datan(1.d0)
+!
       do i=1,nnfront
         j1=istartfront(i)
         j2=iendfront(i)
@@ -198,6 +200,52 @@
           xa(3,j)=xt(1,j)*xn(2,j)-xt(2,j)*xn(1,j)
         enddo
       enddo
+!
+!     calculate a fictituous opening angle for each crack front        
+!     
+      do i=1,nnfront
+        j1=istartfront(i)
+        j2=iendfront(i)
+!     
+        if(isubsurffront(i).ne.1) then
+!     
+!     for surface cracks: calculate the angle between the tangents
+!     at the crossing points of the crack fronts with the free
+!     surface; can be used to determine an appropriate shape factor
+!     in shapefactor.f
+!     
+          angle(i)=xt(1,j1)*xt(1,j2)+xt(2,j1)*xt(2,j2)+xt(3,j1)*xt(3,j2)
+          angle(i)=min(max(angle(i),-1.d0),1.d0)
+!     
+!     if cos(angle(i))<0, i.e. pi/2 < angle(i) < 3*pi/2, a
+!     check is performed whether angle(i) > pi or
+!     angle (i) < pi 
+!     (the cosine of alpha and (2*pi-alpha) is the same)
+!     
+          if(angle(i).ge.0.d0) then
+            angle(i)=dacos(angle(i))
+          else
+            angle(i)=dacos(angle(i))
+!     
+!     mean normal on the front
+!     
+            do j=1,3
+              xnor(j)=(xn(j,j1)+xn(j,j2))
+            enddo
+!     
+!     check whether angle(i) is less than or greater than pi
+!     (the cosine of alpha and (2*pi-alpha) is the same
+!     
+            det=xnor(1)*(xt(2,j1)*xt(3,j2)-xt(3,j1)*xt(2,j2))+
+     &           xnor(2)*(xt(3,j1)*xt(1,j2)-xt(1,j1)*xt(3,j2))+
+     &           xnor(3)*(xt(1,j1)*xt(2,j2)-xt(2,j1)*xt(1,j2))
+            if(det.lt.0.d0) then
+              angle(i)=2.d0*pi-angle(i)
+            endif
+          endif
+!          
+        endif
+      enddo
 !     
 c     do i=1,nfront
 c     write(*,*) 'createlocalsys xt'
