@@ -1,6 +1,6 @@
 !
 !     CalculiX - A 3-dimensional finite element program
-!              Copyright (C) 1998-2022 Guido Dhondt
+!              Copyright (C) 1998-2023 Guido Dhondt
 !
 !     This program is free software; you can redistribute it and/or
 !     modify it under the terms of the GNU General Public License as
@@ -231,8 +231,8 @@
      &  ialset(*),ntie,integerglob(*),nasym,nplicon(0:ntmat_,*),
      &  nplkcon(0:ntmat_,*),npmat_,jjj,id,ig
 !
-      real*8 co(3,*),xl(3,26),veold(0:mi(2),*),rho,s(60,60),bodyfx(3),
-     &  ff(60),elconloc(21),coords(3),p1(3),elcon(0:ncmat_,ntmat_,*),
+      real*8 co(3,*),xl(3,20),veold(0:mi(2),*),rho,s(60,60),bodyfx(3),
+     &  ff(60),elconloc(ncmat_),coords(3),p1(3),
      &  p2(3),eth(6),rhcon(0:1,ntmat_,*),reltime,prop(*),tm(3,3),
      &  alcon(0:6,ntmat_,*),alzero(*),orab(7,*),t0(*),t1(*),
      &  xloadold(2,*),vold(0:mi(2),*),xload(2,*),omx,e,un,um,tt,
@@ -243,7 +243,7 @@
      &  x(3,3),Ds(2,2),Qs(2,2),Qin(3,3),Dm(3,3),Db(3,3),Dc(3,3),
      &  Kp(18,18),Km(18,18),tmg(18,18),Kshell(18,18),dett,dettt,
      &  Mshell(18,18),Dmi(3,3),Dbi(3,3),Dsi(2,2),di,gpthick(3,2),
-     &  pres,fpres(18),Ae
+     &  pres,fpres(18),Ae,elcon(0:ncmat_,ntmat_,*)
       !      
       gpthick(1,1) = +1.d0
       gpthick(2,1) =  0.d0
