@@ -1,5 +1,5 @@
 !     CalculiX - A 3-dimensional finite element program
-!     Copyright (C) 1998-2022 Guido Dhondt
+!     Copyright (C) 1998-2023 Guido Dhondt
 !     
 !     This program is free software; you can redistribute it and/or
 !     modify it under the terms of the GNU General Public License as
@@ -31,11 +31,11 @@
       implicit none
 !     
       integer i,k,m,n1,n2,istartfront(*),iendfront(*),iendcrackfro(*),
-     &     nnfront,ifrontprop(*),nodesnum,ier,icrack,id,nk,nfront,
-     &     ifronteq(*),kend,istartfronteq(*),iendfronteq(*),nfronteq,
-     &     iincglob(*),iinc,ncyctot,nklim
+     &     nnfront,ifrontprop(*),nodesnum,ier,icrack,nk,nfront,
+     &     ifronteq(*),istartfronteq(*),iendfronteq(*),nfronteq,
+     &     iincglob(*),iinc,ncyctot,nklim,mm,j
 !     
-      real*8 co(3,*),dist,charlen(*),x(nfront),px,delta,x1,x2,
+      real*8 co(3,*),dist,charlen(*),x1,x2,
      &     acrackglob(*),dnglob(*)
 !
       nklim=nk+2*nfront
@@ -48,27 +48,10 @@
         istartfronteq(i)=nfronteq+1
 !     
 !     loop over all nodes belonging to the propagated front
-!     
-        k=1
-        x(1)=0.d0
 !     
         if(iendcrackfro(icrack).lt.istartfront(i)) then
           icrack=icrack+1
         endif
-!        
-        do m=istartfront(i),iendfront(i)-1
-!     
-!     distance between two adjacent propagated nodes
-!     
-          n1=ifrontprop(m)
-          n2=ifrontprop(m+1)
-          dist=dsqrt((co(1,n2)-co(1,n1))**2+
-     &         (co(2,n2)-co(2,n1))**2+
-     &         (co(3,n2)-co(3,n2))**2)
-          k=k+1
-          x(k)=x(k-1)+dist
-        enddo
-        kend=k
 !
 !     first node of front (position is not changed); done
 !     for consistency in the node numbering along the crack front        
@@ -86,57 +69,44 @@
         iincglob(nk)=iinc+1
         dnglob(nk)=1.d0*ncyctot
         ifronteq(istartfronteq(i))=nk
-!     
-!     nodesnum is the new number of new nodes on the propagated front
-!     
-        nodesnum=nint(x(kend)/charlen(icrack))+1
-        if(nk+nodesnum-1.gt.nklim) then
-          write(*,*) '*ERROR in eqspacednodes: nfronteq > 2*nfront'
-          ier=1
-          return
-        endif
-        delta=x(kend)/(nodesnum-1)
-!     
-!     treating the nodes in between start and end
-!     
-        do m=1,nodesnum-2
-          px=m*delta
-          call ident(x,px,kend,id)
-          nk=nk+1
-          x1=(x(id+1)-px)/(x(id+1)-x(id))
-          x2=1.d0-x1
-          n1=ifrontprop(istartfront(i)-1+id)
-          n2=ifrontprop(istartfront(i)+id)
-          do k=1,3
-            co(k,nk)=x1*co(k,n1)+x2*co(k,n2)
+!
+        m=0
+        n1=0
+        do mm=istartfront(i)+1,iendfront(i)
+c          n1=ifrontprop(mm-1)
+          if(n1.eq.0) n1=ifrontprop(mm-1)
+          n2=ifrontprop(mm)
+          dist=dsqrt((co(1,n2)-co(1,n1))**2+
+     &         (co(2,n2)-co(2,n1))**2+
+     &         (co(3,n2)-co(3,n1))**2)
+          nodesnum=nint(dist/charlen(icrack))
+          if(nodesnum.eq.0) cycle
+          do j=1,nodesnum
+            x2=(1.d0*j)/nodesnum
+            x1=1.d0-x2
+            nk=nk+1
+            if(nk.gt.nklim) then
+              write(*,*)
+     &             '*ERROR in eqspacednodes: nfronteq>2*nfront'
+              ier=1
+              return
+            endif
+            m=m+1
+            do k=1,3
+              co(k,nk)=x1*co(k,n1)+x2*co(k,n2)
+            enddo
+            acrackglob(nk)=x1*acrackglob(n1)+x2*acrackglob(n2)
+            iincglob(nk)=iinc+1
+            dnglob(nk)=1.d0*ncyctot
+            ifronteq(istartfronteq(i)+m)=nk
           enddo
-          acrackglob(nk)=x1*acrackglob(n1)+x2*acrackglob(n2)
-          iincglob(nk)=iinc+1
-          dnglob(nk)=1.d0*ncyctot
-          ifronteq(istartfronteq(i)+m)=nk
+          n1=n2
         enddo
 !     
-!     ifronteq contains the equivalent front nodes
+!       ifronteq contains the equivalent front nodes
 !     
-        nfronteq=nfronteq+nodesnum
+        nfronteq=nfronteq+m+1
         iendfronteq(i)=nfronteq
-!
-!     last node of front (position is not changed); done
-!     for consistency in the node numbering along the crack front        
-!
-        nk=nk+1
-        do k=1,3
-          co(k,nk)=co(k,ifrontprop(iendfront(i)))
-        enddo
-        acrackglob(nk)=acrackglob(ifrontprop(iendfront(i)))
-        iincglob(nk)=iinc+1
-        dnglob(nk)=1.d0*ncyctot
-        ifronteq(iendfronteq(i))=nk
-!        
-c        if(nfronteq.gt.(2*nfront)) then
-c          write(*,*) '*ERROR in calccharlength: nfronteq.gt.2*nfront'
-c          ier=1
-c        endif
 !
       enddo
       return
