@@ -1,6 +1,6 @@
 !
 !     CalculiX - A 3-dimensional finite element program
-!              Copyright (C) 1998-2022 Guido Dhondt
+!              Copyright (C) 1998-2023 Guido Dhondt
 !
 !     This program is free software; you can redistribute it and/or
 !     modify it under the terms of the GNU General Public License as
@@ -18,7 +18,7 @@
 !
       subroutine extrapolate(yi,yn,ipkon,inum,kon,lakon,nfield,nk,
      &  ne,mi,ndim,orab,ielorien,co,iorienloc,cflag,
-     &  vold,force,ielmat,thicke,ielprop,prop)
+     &  vold,iforce,ielmat,thicke,ielprop,prop)
 !
 !     extrapolates field values at the integration points to the 
 !     nodes
@@ -35,8 +35,6 @@
 !     done in the global (0) or local (1) system
 !
       implicit none
-!
-      logical force
 !
       character*1 cflag
       character*8 lakon(*),lakonl
@@ -46,7 +44,7 @@
      &  nonei15(3,9),iorienloc,iorien,ielorien(mi(3),*),konl,
      &  mint3d,m,iflag,jj,ll,ielmat(mi(3),*),ielprop(*),
      &  nlayer,nopeexp,ilayer,kk,mint2d,nopes,kl,ki,null,
-     &  itet(4),iwedge(2,9)
+     &  itet(4),iwedge(2,9),iforce
 !
       real*8 yi(ndim,mi(1),*),yn(nfield,*),field(999,20*mi(3)),a8(8,8),
      &  a4(4,4),a27(20,27),a9(6,9),a2(6,2),orab(7,*),co(3,*),prop(*),
@@ -414,7 +412,7 @@
          elseif(lakonl(1:1).eq.'U') then
             call extrapolate_u(yi,yn,ipkon,inum,kon,lakon,nfield,nk,
      &           ne,mi,ndim,orab,ielorien,co,iorienloc,cflag,
-     &           vold,force,ielmat,thicke,ielprop,prop,i)
+     &           vold,iforce,ielmat,thicke,ielprop,prop,i)
             cycle
          else
             cycle
@@ -1069,7 +1067,7 @@ c     Bernhardi end
 !
       if((cflag.ne.' ').and.(cflag.ne.'E')) then
          call map3dto1d2d(yn,ipkon,inum,kon,lakon,nfield,nk,ne,cflag,
-     &         co,vold,force,mi,ielprop,prop)
+     &         co,vold,iforce,mi,ielprop,prop)
       endif
 !
       return
