@@ -1,5 +1,5 @@
 /*     CalculiX - A 3-dimensional finite element program                 */
-/*              Copyright (C) 1998-2022 Guido Dhondt                          */
+/*              Copyright (C) 1998-2023 Guido Dhondt                          */
 
 /*     This program is free software; you can redistribute it and/or     */
 /*     modify it under the terms of the GNU General Public License as    */
@@ -88,7 +88,7 @@ void frd(double *co,ITG *nk,ITG *kon,ITG *ipkon,char *lakon,ITG *ne0,
 
   double pi,oner,*errn=NULL,*ethn=NULL;
 
-  strcpy(fneig,jobnamec);
+  strcpy2(fneig,jobnamec,132);
   strcat(fneig,".frd");
 
   if((f1=fopen(fneig,"ab"))==NULL){
@@ -199,8 +199,8 @@ void frd(double *co,ITG *nk,ITG *kon,ITG *ipkon,char *lakon,ITG *ne0,
     fprintf(f1,"%5sUTIME              %8s                                        \n",p1,newclock);
     fprintf(f1,"%5sUHOST                                                              \n",p1);
     fprintf(f1,"%5sUPGM               CalculiX                                        \n",p1);
-    fprintf(f1,"%5sUVERSION           Version 2.20                             \n",p1);
-    fprintf(f1,"%5sUCOMPILETIME       Sun Jul 31 18:08:37 CEST 2022                    \n",p1);
+    fprintf(f1,"%5sUVERSION           Version 2.21                             \n",p1);
+    fprintf(f1,"%5sUCOMPILETIME       Sat Jul 29 10:52:01 CEST 2023                    \n",p1);
     fprintf(f1,"%5sUDIR                                                               \n",p1);
     fprintf(f1,"%5sUDBN                                                               \n",p1);
     
@@ -289,8 +289,13 @@ void frd(double *co,ITG *nk,ITG *kon,ITG *ipkon,char *lakon,ITG *ne0,
 
 	  /* user element */
 
-	}else if(strcmp1(&lakon[8*i],"U1")==0){
-	  continue;
+	}else if(strcmp1(&lakon[8*i],"U")==0){
+
+	/* only user elements of type US3 and US45 are stored */
+	
+	  if((strcmp1(&lakon[8*i],"US3")!=0)&&(strcmp1(&lakon[8*i],"US45")!=0)){
+	    continue;
+	  }
 	}
 	nelout++;
       }
@@ -330,8 +335,14 @@ void frd(double *co,ITG *nk,ITG *kon,ITG *ipkon,char *lakon,ITG *ne0,
 	continue;
       }else if(strcmp1(&lakon[8*i],"MASS")==0){
 	continue;
-      }else if(strcmp1(&lakon[8*i],"U1")==0){
-	continue;
+      }else if(strcmp1(&lakon[8*i],"U")==0){
+
+	/* only user elements of type US3 and US45 are stored */
+	
+	if((strcmp1(&lakon[8*i],"US3")!=0)&&(strcmp1(&lakon[8*i],"US45")!=0)){
+	  continue;
+	}
+	indexe=ipkon[i];
       }else{
 	indexe=ipkon[i];
       }
@@ -1377,10 +1388,20 @@ void frd(double *co,ITG *nk,ITG *kon,ITG *ipkon,char *lakon,ITG *ne0,
   }
 
   /* storing the imaginary part of the mechanical strains in the nodes
-     for the odd modes of cyclic symmetry calculations */
+     for the odd modes of cyclic symmetry calculations or for
+     steady state calculations */
   
   if((*noddiam>=0)||((*nmethod==5)&&(*mode==0))){
     if((strcmp1(&filab[2697],"ME  ")==0)&&(*ithermal!=2)){
+
+      /* check for a set in steady state calculations */
+      
+      if((*nmethod==5)&&(*mode==0)){
+	iselect=1;
+	frdset(&filab[2697],set,&iset,istartset,iendset,ialset,
+	       inum,&noutloc,&nout,nset,&noutmin,&noutplus,&iselect,
+	       ngraph);
+      }
       
       frdheader(&icounter,&oner,time,&pi,noddiam,cs,&null,mode,
 		&noutloc,description,kode,nmethod,f1,output,istep,iinc);
@@ -1392,10 +1413,16 @@ void frd(double *co,ITG *nk,ITG *kon,ITG *ipkon,char *lakon,ITG *ne0,
       fprintf(f1," -5  MEXY        1    4    1    2\n");
       fprintf(f1," -5  MEYZ        1    4    2    3\n");
       fprintf(f1," -5  MEZX        1    4    3    1\n");
-      
-      frdselect(&emn[6**nk],een,&iset,&nkcoords,inum,m1,istartset,iendset,
-                ialset,ngraph,&ncomptensor,ifieldtensor,icomptensor,
-                nfieldtensor,&iselect,m2,f1,output,m3);
+
+      if(*noddiam>=0){
+	frdselect(&emn[6**nk],een,&iset,&nkcoords,inum,m1,istartset,iendset,
+		  ialset,ngraph,&ncomptensor,ifieldtensor,icomptensor,
+		  nfieldtensor,&iselect,m2,f1,output,m3);
+      }else{
+	frdselect(emn,emn,&iset,&nkcoords,inum,m1,istartset,iendset,
+		  ialset,ngraph,&ncomptensor,ifieldtensor,icomptensor,
+		  nfieldtensor,&iselect,m2,f1,output,m3);
+      }
       
     }
   }
@@ -1486,10 +1513,20 @@ void frd(double *co,ITG *nk,ITG *kon,ITG *ipkon,char *lakon,ITG *ne0,
   }
 
   /*     storing the imaginary part of the forces in the nodes
-         for the odd modes of cyclic symmetry calculations */
+         for the odd modes of cyclic symmetry calculations or for
+         steady state calculations */
 
   if((*noddiam>=0)||((*nmethod==5)&&(*mode==0))){
     if((strcmp1(&filab[348],"RF  ")==0)&&(*ithermal!=2)){
+
+      /* check for a set in steady state calculations */
+      
+      if((*nmethod==5)&&(*mode==0)){
+	iselect=1;
+	frdset(&filab[348],set,&iset,istartset,iendset,ialset,
+	       inum,&noutloc,&nout,nset,&noutmin,&noutplus,&iselect,
+	       ngraph);
+      }
     
       frdheader(&icounter,&oner,time,&pi,noddiam,cs,&null,mode,
 		&noutloc,description,kode,nmethod,f1,output,istep,iinc);
@@ -1500,8 +1537,13 @@ void frd(double *co,ITG *nk,ITG *kon,ITG *ipkon,char *lakon,ITG *ne0,
       fprintf(f1," -5  F3          1    2    3    0\n");
       fprintf(f1," -5  ALL         1    2    0    0    1ALL\n");
       
-      frdvector(&fn[*nk*mt],&iset,ntrans,filab,&nkcoords,inum,m1,inotr,
-		trab,co,istartset,iendset,ialset,mi,ngraph,f1,output,m3);
+      if(*noddiam>=0){
+	frdvector(&fn[*nk*mt],&iset,ntrans,filab,&nkcoords,inum,m1,inotr,
+		  trab,co,istartset,iendset,ialset,mi,ngraph,f1,output,m3);
+      }else{
+	frdvector(fn,&iset,ntrans,filab,&nkcoords,inum,m1,inotr,
+		  trab,co,istartset,iendset,ialset,mi,ngraph,f1,output,m3);
+      }
     }
   }
 
@@ -1565,12 +1607,12 @@ void frd(double *co,ITG *nk,ITG *kon,ITG *ipkon,char *lakon,ITG *ne0,
 	      &noutloc,description,kode,nmethod,f1,output,istep,iinc);
     
     fprintf(f1," -4  CONTACT     6    1\n");
-    fprintf(f1," -5  COPEN       1    4    1    1\n");
-    fprintf(f1," -5  CSLIP1      1    4    2    2\n");
-    fprintf(f1," -5  CSLIP2      1    4    3    3\n");
-    fprintf(f1," -5  CPRESS      1    4    1    2\n");
-    fprintf(f1," -5  CSHEAR1     1    4    2    3\n");
-    fprintf(f1," -5  CSHEAR2     1    4    3    1\n");
+    fprintf(f1," -5  COPEN       1    1    0    0\n");
+    fprintf(f1," -5  CSLIP1      1    1    0    0\n");
+    fprintf(f1," -5  CSLIP2      1    1    0    0\n");
+    fprintf(f1," -5  CPRESS      1    1    0    0\n");
+    fprintf(f1," -5  CSHEAR1     1    1    0    0\n");
+    fprintf(f1," -5  CSHEAR2     1    1    0    0\n");
     
     for(i=*ne-1;i>=0;i--){
       if((strcmp1(&lakon[8*i+1],"S")!=0)||(strcmp1(&lakon[8*i+6],"C")!=0))
@@ -1613,12 +1655,12 @@ void frd(double *co,ITG *nk,ITG *kon,ITG *ipkon,char *lakon,ITG *ne0,
       frdheader(&icounter,&oner,time,&pi,noddiam,cs,&null,mode,
 		&noutloc,description,kode,nmethod,f1,output,istep,iinc);
       fprintf(f1," -4  CONTACT     6    1\n");
-      fprintf(f1," -5  COPEN       1    4    1    1\n");
-      fprintf(f1," -5  CSLIP1      1    4    2    2\n");
-      fprintf(f1," -5  CSLIP2      1    4    3    3\n");
-      fprintf(f1," -5  CPRESS      1    4    1    2\n");
-      fprintf(f1," -5  CSHEAR1     1    4    2    3\n");
-      fprintf(f1," -5  CSHEAR2     1    4    3    1\n");
+      fprintf(f1," -5  COPEN       1    1    0    0\n");
+      fprintf(f1," -5  CSLIP1      1    1    0    0\n");
+      fprintf(f1," -5  CSLIP2      1    1    0    0\n");
+      fprintf(f1," -5  CPRESS      1    1    0    0\n");
+      fprintf(f1," -5  CSHEAR1     1    1    0    0\n");
+      fprintf(f1," -5  CSHEAR2     1    1    0    0\n");
   
       frdselect(cdn,cdn,&iset,&nkcoords,inum,m1,istartset,iendset,
 		ialset,ngraph,&ncomptensor,ifieldtensor,icomptensor,
@@ -1629,21 +1671,22 @@ void frd(double *co,ITG *nk,ITG *kon,ITG *ipkon,char *lakon,ITG *ne0,
 
   /* storing imaginary part of the differential contact displacements 
      and the contact stresses for the odd modes of cyclic symmetry
-     calculations */
+     calculations (only face-to-face penalty) */
 
-  if((*noddiam>=0)||((*nmethod==5)&&(*mode==0))){
+  //  if((*noddiam>=0)||((*nmethod==5)&&(*mode==0))){
+  if(*noddiam>=0){
     if((strcmp1(&filab[2175],"CONT")==0)&&(*mortar==1)&&(*ithermal!=2)){
       iselect=1;
-  
+      
       frdheader(&icounter,&oner,time,&pi,noddiam,cs,&null,mode,
 		&noutloc,description,kode,nmethod,f1,output,istep,iinc);
       fprintf(f1," -4  CONTACTI    6    1\n");
-      fprintf(f1," -5  COPEN       1    4    1    1\n");
-      fprintf(f1," -5  CSLIP1      1    4    2    2\n");
-      fprintf(f1," -5  CSLIP2      1    4    3    3\n");
-      fprintf(f1," -5  CPRESS      1    4    1    2\n");
-      fprintf(f1," -5  CSHEAR1     1    4    2    3\n");
-      fprintf(f1," -5  CSHEAR2     1    4    3    1\n");
+      fprintf(f1," -5  COPEN       1    1    0    0\n");
+      fprintf(f1," -5  CSLIP1      1    1    0    0\n");
+      fprintf(f1," -5  CSLIP2      1    1    0    0\n");
+      fprintf(f1," -5  CPRESS      1    1    0    0\n");
+      fprintf(f1," -5  CSHEAR1     1    1    0    0\n");
+      fprintf(f1," -5  CSHEAR2     1    1    0    0\n");
   
       frdselect(&cdn[6**nk],cdn,&iset,&nkcoords,inum,m1,istartset,iendset,
 		ialset,ngraph,&ncomptensor,ifieldtensor,icomptensor,
@@ -1673,7 +1716,7 @@ void frd(double *co,ITG *nk,ITG *kon,ITG *ipkon,char *lakon,ITG *ne0,
       nope=atoi(&lakon[8*i+7])+1;
       nodes=kon[ipkon[i]+nope-1];
       if(strcmp1(output,"asc")==0){
-	fprintf(f1,"%3s%10" ITGFORMAT "%12.5E\n",m1,nodes,(float)ener[i*mi[0]]);
+	fprintf(f1,"%3s%10" ITGFORMAT "%12.5E\n",m1,nodes,(float)ener[2*i*mi[0]]);
       }else{
 	iw=(int)(nodes);fwrite(&iw,sizeof(int),1,f1);
 	if(strcmp1(output,"bin")==0){
@@ -1825,13 +1868,29 @@ void frd(double *co,ITG *nk,ITG *kon,ITG *ipkon,char *lakon,ITG *ne0,
 
   /* storing the imaginary part of the Zienkiewicz-Zhu 
      improved stresses in the nodes
-     for the odd modes of cyclic symmetry calculations */
+     for the odd modes of cyclic symmetry calculations or for
+     steady state dynamics calculations */
   
   if((*noddiam>=0)||((*nmethod==5)&&(*mode==0))){
     if((strcmp1(&filab[1044],"ZZS")==0)&&(*ithermal!=2)){
 
-      FORTRAN(zienzhu,(co,nk,kon,ipkon,lakon,ne0,stn,ipneigh,neigh,
-		       &stx[6*mi[0]**ne],&mi[0]));
+      if(*noddiam>=0){
+
+	/* cyclic symmetry := call from arpackcs.c */
+	
+	FORTRAN(zienzhu,(co,nk,kon,ipkon,lakon,ne0,stn,ipneigh,neigh,
+			 &stx[6*mi[0]**ne],&mi[0]));
+      }else{
+
+	/* steady state := call from steadystate.c */
+	
+	FORTRAN(zienzhu,(co,nk,kon,ipkon,lakon,ne0,stn,ipneigh,neigh,
+			 stx,&mi[0]));
+	iselect=1;
+	frdset(&filab[1044],set,&iset,istartset,iendset,ialset,
+	       inum,&noutloc,&nout,nset,&noutmin,&noutplus,&iselect,
+	       ngraph);
+      }	
       
       frdheader(&icounter,&oner,time,&pi,noddiam,cs,&null,mode,
 		&noutloc,description,kode,nmethod,f1,output,istep,iinc);
@@ -1887,15 +1946,26 @@ void frd(double *co,ITG *nk,ITG *kon,ITG *ipkon,char *lakon,ITG *ne0,
   }
 
   /* storing the imaginary part of the error estimator in the nodes
-     for the odd modes of cyclic symmetry calculations */
+     for the odd modes of cyclic symmetry calculations or for
+     steady state dynamics calculations */
   
   if((*noddiam>=0)||((*nmethod==5)&&(*mode==0))){
     if((strcmp1(&filab[1044],"ERR")==0)&&(*ithermal!=2)){
 
       nterms=6;
-      FORTRAN(errorestimator,(&stx[6*mi[0]**ne],stn,ipkon,kon,lakon,nk,ne,
-			      mi,ielmat,&nterms,inum,co,v,&filab[1048],
-			      ielprop,prop));
+      if(*noddiam>=0){
+	FORTRAN(errorestimator,(&stx[6*mi[0]**ne],stn,ipkon,kon,lakon,nk,ne,
+				mi,ielmat,&nterms,inum,co,v,&filab[1048],
+				ielprop,prop));
+      }else{
+	FORTRAN(errorestimator,(stx,stn,ipkon,kon,lakon,nk,ne,
+				mi,ielmat,&nterms,inum,co,v,&filab[1048],
+				ielprop,prop));
+	iselect=1;
+	frdset(&filab[1044],set,&iset,istartset,iendset,ialset,
+	       inum,&noutloc,&nout,nset,&noutmin,&noutplus,&iselect,
+	       ngraph);
+      }
       
       frdheader(&icounter,&oner,time,&pi,noddiam,cs,&null,mode,
 		&noutloc,description,kode,nmethod,f1,output,istep,iinc);
