@@ -1,5 +1,5 @@
 /*     CalculiX - A 3-dimensional finite element program                 */
-/*              Copyright (C) 1998-2022 Guido Dhondt                     */
+/*              Copyright (C) 1998-2023 Guido Dhondt                     */
 
 /*     This program is free software; you can redistribute it and/or     */
 /*     modify it under the terms of the GNU General Public License as    */
@@ -42,9 +42,12 @@ void massless(ITG *kslav,ITG *lslav,ITG *ktot,ITG *ltot,double *au,double *ad,
 	      ITG *jqw,ITG *iroww,ITG *nzsw,ITG *islavnode,ITG *nslavnode,
 	      ITG *nslavs,ITG *imastnode,ITG *nmastnode,ITG *ntie,ITG *nactdof,
 	      ITG *mi,double *vold,double *volddof, double *veold,ITG *nk,
-	      double *fext,ITG *isolver,ITG *iperturb,double *co,
+	      double *fext,ITG *isolver,ITG *masslesslinear,double *co,
 	      double *springarea,ITG *neqtot,double *qb,
-	      double *b,double *tinc,double *aloc,double *fric,ITG *iexpl){
+	      double *b,double *dtime,double *aloc,double *fric,ITG *iexpl,
+	      ITG *nener,double *ener,ITG *ne,ITG **jqbip,double **aubip,
+	      ITG **irowbip,ITG **jqibp,double **auibp,ITG **irowibp,
+	      ITG *iclean,ITG *iinc){
 
   /* determining the RHS of the global system for massless contact */
 
@@ -57,8 +60,30 @@ void massless(ITG *kslav,ITG *lslav,ITG *ktot,ITG *ltot,double *au,double *ad,
     *adbbb=NULL,*aubbb=NULL,*gvec=NULL,*gmatrix=NULL,*qi_kbi=NULL,
     *veolddof=NULL,*alglob=NULL,atol,rtol,*aubb=NULL,*adbb=NULL,
     *al=NULL,*alnew=NULL,*eps_al=NULL,*rhs=NULL,*aubi=NULL,
-    *auib=NULL,omega;
+    *auib=NULL,omega,*alocold=NULL,*ddisp=NULL;
 
+  jqbi=*jqbip;aubi=*aubip;irowbi=*irowbip;jqib=*jqibp;auib=*auibp;
+  irowib=*irowibp;
+
+  /* clearing memory for the equation solver at the end of the step*/
+
+  if(*iclean==1){
+    if(*isolver==0){
+#ifdef SPOOLES
+      spooles_cleanup_rad();
+#endif
+    }else if(*isolver==7){
+#ifdef PARDISO
+      pardiso_cleanup_cp(neqtot,&symmetryflag,&inputformat);
+#endif
+    }else if(*isolver==8){
+#ifdef PASTIX
+      pastix_solve_cp(qb,neqtot,&symmetryflag,&nrhs);
+#endif
+    }
+    return;
+  }
+  
   /* expanding the matrix Wb according to the number of degrees
      of freedom */
 
@@ -79,32 +104,36 @@ void massless(ITG *kslav,ITG *lslav,ITG *ktot,ITG *ltot,double *au,double *ad,
 
   SFREE(jqwnew);SFREE(auwnew);SFREE(irowwnew);
 
-  /* extracting Kbb,Kbi,Kib,Kii from the stiffness matrix */
+  /* extracting Kbb,Kbi,Kib,Kii from the stiffness matrix;
+     only for a nonlinear calculation or the first increment
+     of a linear calculation */
 
-  NNEW(jqbb,ITG,*neqtot+1);
-  NNEW(aubb,double,nzs[0]);
-  NNEW(adbb,double,*neqtot);
-  NNEW(irowbb,ITG,nzs[0]);
-  NNEW(icolbb,ITG,*neqtot);
+  if((*masslesslinear==0)||(*iinc==1)){
+    NNEW(jqbb,ITG,*neqtot+1);
+    NNEW(aubb,double,nzs[0]);
+    NNEW(adbb,double,*neqtot);
+    NNEW(irowbb,ITG,nzs[0]);
+    NNEW(icolbb,ITG,*neqtot);
 
-  NNEW(jqbi,ITG,neq[0]+1);
-  NNEW(aubi,double,nzs[0]);
-  NNEW(irowbi,ITG,nzs[0]);
+    NNEW(jqbi,ITG,neq[0]+1);
+    NNEW(aubi,double,nzs[0]);
+    NNEW(irowbi,ITG,nzs[0]);
 
-  NNEW(jqib,ITG,*neqtot+1);
-  NNEW(auib,double,nzs[0]);
-  NNEW(irowib,ITG,nzs[0]);
+    NNEW(jqib,ITG,*neqtot+1);
+    NNEW(auib,double,nzs[0]);
+    NNEW(irowib,ITG,nzs[0]);
 
-  FORTRAN(extract_matrices,(au,ad,jq,irow,neq,aubb,adbb,jqbb,irowbb,neqtot,
-			    &nzsbb,aubi,jqbi,irowbi,&nzsbi,auib,jqib,irowib,
-			    &nzsib,ktot,icolbb));
+    FORTRAN(extract_matrices,(au,ad,jq,irow,neq,aubb,adbb,jqbb,irowbb,neqtot,
+			      &nzsbb,aubi,jqbi,irowbi,&nzsbi,auib,jqib,irowib,
+			      &nzsib,ktot,icolbb));
 
-  RENEW(aubb,double,nzsbb);
-  RENEW(irowbb,ITG,nzsbb);
-  RENEW(aubi,double,nzsbi);
-  RENEW(irowbi,ITG,nzsbi);
-  RENEW(auib,double,nzsib);
-  RENEW(irowib,ITG,nzsib);
+    RENEW(aubb,double,nzsbb);
+    RENEW(irowbb,ITG,nzsbb);
+    RENEW(aubi,double,nzsbi);
+    RENEW(irowbi,ITG,nzsbi);
+    RENEW(auib,double,nzsib);
+    RENEW(irowib,ITG,nzsib);
+  }
 
   /* calculate the residual force in the contact area and store in gapdisp */
   
@@ -114,42 +143,57 @@ void massless(ITG *kslav,ITG *lslav,ITG *ktot,ITG *ltot,double *au,double *ad,
   FORTRAN(resforccont,(vold,nk,mi,aubi,irowbi,jqbi,neqtot,ktot,fext,gapdisp,
 		       auib,irowib,jqib,nactdof,volddof,neq,qi_kbi));
 
-  /* factorize Kbb and premultiply gapdisp with Kbb^{-1} */
+  /* factorize Kbb and delete Kbb afterwards;
+     only for a nonlinear calculation or the first increment
+     of a linear calculation */
+
+  if((*masslesslinear==0)||(*iinc==1)){
+    if(*isolver==0){
+#ifdef SPOOLES
+      spooles_factor_rad(adbb,aubb,adbbb,aubbb,&sigma,icolbb,irowbb,
+			 neqtot,&nzsbb,&symmetryflag,&inputformat,iexpl);
+#else
+      printf(" *ERROR in massless: the SPOOLES library is not linked\n\n");
+      FORTRAN(stop,());
+#endif
+    }else if(*isolver==7){
+#ifdef PARDISO
+      pardiso_factor_cp(adbb,aubb,adbbb,aubbb,&sigma,icolbb,
+			irowbb,neqtot,&nzsbb,&symmetryflag,&inputformat,jqbb,
+			&nzsbb,iexpl);
+#else
+      printf(" *ERROR in massless: the PARDISO library is not linked\n\n");
+      FORTRAN(stop,());
+#endif
+    }else if(*isolver==8){
+#ifdef PASTIX
+      ITG inputformat=1;
+      pastix_factor_main_cp(adbb,aubb,adbbb,aubbb,&sigma,icolbb,
+			    irowbb,neqtot,&nzsbb,&symmetryflag,&inputformat,
+			    jqbb,&nzsbb);
+#else
+      printf(" *ERROR in massless: the PASTIX library is not linked\n\n");
+      FORTRAN(stop,());
+#endif
+    }
+    SFREE(aubb);SFREE(adbb);SFREE(irowbb);SFREE(icolbb);SFREE(jqbb);
+  }
+
+  /* premultiply gapdisp with Kbb^{-1} */
 
   if(*isolver==0){
 #ifdef SPOOLES
-    spooles_factor_rad(adbb,aubb,adbbb,aubbb,&sigma,icolbb,irowbb,
-		       neqtot,&nzsbb,&symmetryflag,&inputformat,iexpl);
-
     spooles_solve_rad(gapdisp,neqtot);
-#else
-    printf(" *ERROR in massless: the SPOOLES library is not linked\n\n");
-    FORTRAN(stop,());
 #endif
   }else if(*isolver==7){
 #ifdef PARDISO
-    pardiso_factor_cp(adbb,aubb,adbbb,aubbb,&sigma,icolbb,
-		      irowbb,neqtot,&nzsbb,&symmetryflag,&inputformat,jqbb,
-		      &nzsbb,iexpl);
     pardiso_solve_cp(gapdisp,neqtot,&symmetryflag,&inputformat,&nrhs);
-#else
-    printf(" *ERROR in massless: the PARDISO library is not linked\n\n");
-    FORTRAN(stop,());
 #endif
   }else if(*isolver==8){
 #ifdef PASTIX
-    ITG inputformat = 1;
-    pastix_factor_main_cp(adbb,aubb,adbbb,aubbb,&sigma,icolbb,
-			  irowbb,neqtot,&nzsbb,&symmetryflag,&inputformat,jqbb,
-			  &nzsbb);
     pastix_solve_cp(gapdisp,neqtot,&symmetryflag,&nrhs);
-    
-#else
-    printf(" *ERROR in massless: the PASTIX library is not linked\n\n");
-    FORTRAN(stop,());
 #endif
   }
-  SFREE(aubb);SFREE(adbb);SFREE(irowbb);SFREE(icolbb);SFREE(jqbb);
 
   NNEW(gapnorm,double,*nslavs);
   NNEW(iacti,ITG,*neqtot);
@@ -169,15 +213,14 @@ void massless(ITG *kslav,ITG *lslav,ITG *ktot,ITG *ltot,double *au,double *ad,
     NNEW(cvec,double,nacti);
 
     for (i=0;i<*neqtot;i++){
-      gapdisp[i]=(gapdisp[i]-volddof[ktot[i]-1])/(*tinc); // gapdisp - qb_km1
+      gapdisp[i]=(gapdisp[i]-volddof[ktot[i]-1])/(*dtime); // gapdisp - qb_km1
     }
 
     // cvec = Wb^T * cvec
     
     for (i=0;i<3**nslavs;++i){
       if (iacti[i]!=0){
-        index=i;
-        for (j=jqw[index]-1;j<jqw[index+1]-1;j++){
+        for (j=jqw[i]-1;j<jqw[i+1]-1;j++){
           cvec[iacti[i]-1]+=auw[j]*gapdisp[iroww[j]-1];
         }
       }
@@ -194,13 +237,13 @@ void massless(ITG *kslav,ITG *lslav,ITG *ktot,ITG *ltot,double *au,double *ad,
     for(i=0;i<3**nslavs;i++){
       
       if(iacti[i]!=0) {
-	index=i;//  contact index
+	//	index=i;//  contact index
 
 	NNEW(gvec,double,*neqtot);
 
 	/* Filling the vector of Wb column */
 	
-	for(j=jqw[index]-1;j<jqw[index+1]-1;j++){
+	for(j=jqw[i]-1;j<jqw[i+1]-1;j++){
 	  gvec[iroww[j]-1]=auw[j];
 	}
  
@@ -224,12 +267,12 @@ void massless(ITG *kslav,ITG *lslav,ITG *ktot,ITG *ltot,double *au,double *ad,
 
 	for(j=0;j<3**nslavs;++j){
 	  if(iacti[j]!=0){
-	    index=j;
+	    //	    index=j;
 	    sum=0.0;
-	    for(k=jqw[index]-1;k<jqw[index+1]-1;k++){
+	    for(k=jqw[j]-1;k<jqw[j+1]-1;k++){
 	      sum+=auw[k]*gvec[iroww[k]-1];
 	    }
-	    gmatrix[(iacti[i]-1)*nacti+(iacti[j]-1)]= sum / (*tinc) ;
+	    gmatrix[(iacti[i]-1)*nacti+(iacti[j]-1)]= sum / (*dtime) ;
 	  }
 	}
 	SFREE(gvec);
@@ -249,17 +292,17 @@ void massless(ITG *kslav,ITG *lslav,ITG *ktot,ITG *ltot,double *au,double *ad,
     // We control this parameter with OMEGA. Recommended is 100% (no modification) No more than 200% or less than 100%.
     // should not be necesary to decrease it < 100%
     
-    omega = 1.0;
+    omega=1.0;
 
     NNEW(al,double,nacti);
     NNEW(alnew,double,nacti);
     
     // taking values from aloc for initial guess
     
-    for (int i=0;i<3**nslavs;++i){
+    for (i=0;i<3**nslavs;++i){
       if (iacti[i]!=0){
-	al[iacti[i]-1]    = aloc[i];
-	alnew[iacti[i]-1] = aloc[i];
+	al[iacti[i]-1]=aloc[i];
+	alnew[iacti[i]-1]=aloc[i];
       }
     }
 
@@ -270,11 +313,16 @@ void massless(ITG *kslav,ITG *lslav,ITG *ktot,ITG *ltot,double *au,double *ad,
 	     alglob,&kitermax,auw,jqw,iroww,nslavs,al,
 	     alnew,eps_al,&omega));
 
+    if(*nener==1){
+      NNEW(alocold,double,3**nslavs);
+      memcpy(&alocold[0],&aloc[0],sizeof(double)*3**nslavs);
+    }
+    
     // storing back values for next initial guess
     
-    for (int i=0;i<3**nslavs;++i){
-      if (iacti[i]!=0){
-	aloc[i] = alnew[iacti[i]-1];
+    for(i=0;i<3**nslavs;++i){
+      if(iacti[i]!=0){
+	aloc[i]=alnew[iacti[i]-1];
       }
     }
     SFREE(al);
@@ -282,13 +330,13 @@ void massless(ITG *kslav,ITG *lslav,ITG *ktot,ITG *ltot,double *au,double *ad,
     SFREE(eps_al);
     SFREE(gmatrix);
     SFREE(cvec);
-
+    
   }else{
     NNEW(alglob,double,*neqtot);
   }
+
   SFREE(gapdisp); // TODO CMT move this freeing, we need it still
   SFREE(gapnorm);
-  SFREE(iacti);
   
   /* compute  qb = Kbb^{-1}*(Wb*al-qi_kbi+fexb) */
 
@@ -310,9 +358,46 @@ void massless(ITG *kslav,ITG *lslav,ITG *ktot,ITG *ltot,double *au,double *ad,
 #endif
   }
 
-  SFREE(alglob);
-  SFREE(qi_kbi);
+  SFREE(alglob);SFREE(qi_kbi);
 
+  /* compute the energy dissipated by friction */
+
+  if(*nener==1){
+
+    /* relative tangential displacements in this increment
+       in a local coordinate system: Wb^T*(qb^{n+1}-qb^n) */
+
+    NNEW(ddisp,double,3**nslavs);
+    for(i=0;i<3**nslavs;i++){
+
+      /* treat only tangential direction */
+
+      if(3*(i/3)!=i){
+
+	/* treat only active slave nodes */
+	
+	if(iacti[i]!=0){
+	  for(j=jqw[i]-1;j<jqw[i+1]-1;j++){
+	    ddisp[i]+=auw[j]*(qb[iroww[j]-1]-volddof[ktot[iroww[j]-1]-1]);
+	  }
+	}
+      }
+    }
+
+    /* friction energy increase = (al^{n+1}+al^n)/2*Wb^T*(qb^{n+1}-qb^n) */
+    
+    for(i=0;i<3**nslavs;i++){
+      if(3*(i/3)!=i){
+	if(iacti[i]!=0){
+	  ener[2*mi[0]*(*ne+i/3)+1]+=-(alocold[i]+aloc[i])*ddisp[i]/2.;
+	}
+      }
+    }
+    SFREE(alocold);SFREE(ddisp);
+  }
+  
+  SFREE(iacti);
+  
   /* compute the right hand side of the global equation system */
   
   /* calculate Kii*qi */
@@ -326,9 +411,13 @@ void massless(ITG *kslav,ITG *lslav,ITG *ktot,ITG *ltot,double *au,double *ad,
   FORTRAN(mulmatvec_asym,(auib,jqib,irowib,neqtot,qb,rhs,&itranspose));
   itranspose=1;
   FORTRAN(mulmatvec_asym,(aubi,jqbi,irowbi,&neq[0],qb,rhs,&itranspose));
-  
-  SFREE(jqbi);SFREE(aubi);SFREE(irowbi);SFREE(jqib);SFREE(auib);SFREE(irowib);
 
+  /* deleting the matrices Kbi and Kib only in the nonlinear case */
+  
+  if(*masslesslinear==0){
+    SFREE(jqbi);SFREE(aubi);SFREE(irowbi);SFREE(jqib);SFREE(auib);SFREE(irowib);
+  }
+    
   /* calculate (Mii/Delta_t-Dii/2)*u_i^{k-1/2} */
 
   /* switch for the velocity from a nodal to a dof representation */
@@ -348,22 +437,28 @@ void massless(ITG *kslav,ITG *lslav,ITG *ktot,ITG *ltot,double *au,double *ad,
   SFREE(rhs);
   SFREE(veolddof);
 
-  /* clearing memory for the equation solver */
-  
-  if(*isolver==0){
+  /* clearing memory for the equation solver;
+     only in the nonlinear case */
+
+  if(*masslesslinear==0){
+    if(*isolver==0){
 #ifdef SPOOLES
-    spooles_cleanup_rad();
+      spooles_cleanup_rad();
 #endif
-  }else if(*isolver==7){
+    }else if(*isolver==7){
 #ifdef PARDISO
-    pardiso_cleanup_cp(neqtot,&symmetryflag,&inputformat);
+      pardiso_cleanup_cp(neqtot,&symmetryflag,&inputformat);
 #endif
-  }else if(*isolver==8){
+    }else if(*isolver==8){
 #ifdef PASTIX
-    pastix_solve_cp(qb,neqtot,&symmetryflag,&nrhs);
+      pastix_solve_cp(qb,neqtot,&symmetryflag,&nrhs);
 #endif
+    }
   }
 
+  *jqbip=jqbi;*aubip=aubi;*irowbip=irowbi;*jqibp=jqib;*auibp=auib;
+  *irowibp=irowib;
+
   return;
 }
 
