@@ -1,5 +1,5 @@
 /*     CalculiX - A 3-dimensional finite element program                 */
-/*              Copyright (C) 1998-2022 Guido Dhondt                          */
+/*              Copyright (C) 1998-2023 Guido Dhondt                          */
 
 /*     This program is free software; you can redistribute it and/or     */
 /*     modify it under the terms of the GNU General Public License as    */
@@ -49,8 +49,7 @@ static ITG *kon1,*ipkon1,*ne1,*nelcon1,*nrhcon1,*nalcon1,*ielmat1,*ielorien1,
   num_cpuse,*neapar2=NULL,*nebpar2=NULL,*ialdesi1,
   *ialnk1,*ialeneigh1,*ialnneigh1,*ipos1,*nodedesired1,*istarteneigh1,
   *istartnneigh1,*nactdofred1,*nactdofinv1,*mt1,*istartnk1,
-  *iponod2dto3d1;
-    
+  *nod2nd3rd1;
     
 static double *co1,*v1,*stx1,*elcon1,*rhcon1,*alcon1,*alzero1,*orab1,*t01,*t11,
   *prestr1,*vold1,*veold1,*dtime1,*time1,*xdesi1,*depn1,*dxstate1,
@@ -58,8 +57,7 @@ static double *co1,*v1,*stx1,*elcon1,*rhcon1,*alcon1,*alzero1,*orab1,*t01,*t11,
   *vini1,*ener1,*eei1,*enerini1,*springarea1,*reltime1,*thicke1,*emeini1,
   *prop1,*pslavsurf1,*pmastsurf1,*clearini1,*distmin1,*g01,*dgdx1,
   *sti1,*xmass1=NULL,*xener1=NULL,*epn1,*stn1,*dv1,*dstn1,*dstx1,*expks1,*dgdu1,
-  dispmin1,*conew1;
-    
+  dispmin1,*conew1,*physcon1;
 
 void objectivemain_se(double *co,ITG *nk,ITG *kon,ITG *ipkon,char *lakon,
 		      ITG *ne,double *v,double *stn,ITG *inum,double *stx,
@@ -106,10 +104,11 @@ void objectivemain_se(double *co,ITG *nk,ITG *kon,ITG *ipkon,char *lakon,
 		      ITG *nzss,ITG *nev,ITG *ishapeenergy,double *fint,
 		      ITG *nlabel,ITG *igreen,ITG *nasym,ITG *iponoel,
 		      ITG *inoel,ITG *nodedesiinv,double *dgdxglob,
-		      ITG *nkon,ITG *iponod2dto3d,
-		      ITG *iponk2dto3d,ITG *ics,ITG *mcs,ITG *mpcend,
+		      ITG *nkon,ITG *nod2nd3rd,
+		      ITG *nod1st,ITG *ics,ITG *mcs,ITG *mpcend,
 		      ITG *noddiam,ITG *ipobody,ITG *ibody,double *xbody,
-		      ITG *nbody,ITG *nobjectstart,double *dfm){
+		      ITG *nbody,ITG *nobjectstart,double *dfm,double *physcon,
+		      ITG *ne2d){
 
   char description[13]="            ",cflag[1]=" ",*filabl=NULL;
 
@@ -121,7 +120,7 @@ void objectivemain_se(double *co,ITG *nk,ITG *kon,ITG *ipkon,char *lakon,
     *istartnk,*ialnk,*istartnneigh=NULL,*ialnneigh=NULL,*ichecknodes=NULL,
     *icheckelems=NULL,*istarteneigh=NULL,*ialeneigh=NULL,neielemtot,
     *nkinsetinv=NULL,ndesired,*nodedesired=NULL,neqred,lprev,ilength,
-    *nactdofred=NULL,ipos,icomplex,ij,id,ishape=0;
+    *nactdofred=NULL,ipos,icomplex,ij,id,ishape=0,ifeasd=0;
 	
   double sigma=0.,ptime=0.,*temp=NULL,*bfix=NULL,*vnew=NULL,*dstn=NULL,
     freq,*c=NULL,orabsav[7],rotvec[3],a[9],pgauss[3],*b=NULL,dispmin=1.e-8,
@@ -244,12 +243,12 @@ void objectivemain_se(double *co,ITG *nk,ITG *kon,ITG *ipkon,char *lakon,
       NNEW(xmass1,double,*ne);
 
       /* deactivating the elements which are not part of the 
-	 target function */
+	 design response */
 
       FORTRAN(actideacti,(set,nset,istartset,iendset,ialset,objectset,
 			  ipkon,&iobject,ne));
  
-      /* call without perturbation */
+      /* call without perturbation (calculation of g0) */
    
       idesvar=0;
 
@@ -333,7 +332,7 @@ void objectivemain_se(double *co,ITG *nk,ITG *kon,ITG *ipkon,char *lakon,
       FORTRAN(actideacti,(set,nset,istartset,iendset,ialset,objectset,
 			  ipkon,&iobject,ne));
  
-      /* call without perturbation */
+      /* call without perturbation (calculation of g0) */
    
       idesvar=0;
 	    
@@ -367,7 +366,7 @@ void objectivemain_se(double *co,ITG *nk,ITG *kon,ITG *ipkon,char *lakon,
       clearini1=clearini;ielprop1=ielprop;prop1=prop;
       distmin1=distmin;ndesi1=ndesi;nodedesi1=nodedesi;
       nobject1=nobject;iobject1=iobject;sti1=sti;istartdesi1=istartdesi;
-      ialdesi1=ialdesi;xdesi1=xdesi;idesvar1=idesvar;
+      ialdesi1=ialdesi;xdesi1=xdesi;idesvar1=idesvar;physcon1=physcon;
 	    
       if(((*nmethod!=4)&&(*nmethod!=5))||(iperturb[0]>1)){
 	printf(" Using up to %" ITGFORMAT " cpu(s) for the strain energy sensitivity.\n\n", num_cpuse);
@@ -375,7 +374,7 @@ void objectivemain_se(double *co,ITG *nk,ITG *kon,ITG *ipkon,char *lakon,
 	    
       NNEW(ithread,ITG,num_cpuse);
 	    
-      /* Total difference of the internal strain energy */
+      /* calculate g0 */
       /* create threads and wait */
 	    
       for(i=0;i<num_cpuse;i++)  {
@@ -414,7 +413,8 @@ void objectivemain_se(double *co,ITG *nk,ITG *kon,ITG *ipkon,char *lakon,
 					pmastsurf,mortar,clearini,&nea,&neb,
 					ielprop,prop,distmin,ndesi,nodedesi,
 					nobject,g0,dgdx,&iobject,sti,xener1,
-					istartdesi,ialdesi,xdesi,&idesvar));
+					istartdesi,ialdesi,xdesi,&idesvar,
+					physcon));
 
       }
 
@@ -466,7 +466,7 @@ void objectivemain_se(double *co,ITG *nk,ITG *kon,ITG *ipkon,char *lakon,
 
       FORTRAN(objective_shapeener_tot,(ne,kon,ipkon,lakon,fint,vold,iperturb,
 				       mi,nactdof,dgdx,df,ndesi,&iobject,jqs,
-				       irows,vec,iponk2dto3d));
+				       irows,vec,nod1st));
 	    
       SFREE(vec);
 	    
@@ -746,7 +746,7 @@ void objectivemain_se(double *co,ITG *nk,ITG *kon,ITG *ipkon,char *lakon,
 		  ne,cs,set,nset,istartset,iendset,ialset,
 		  jobnamec,output,temp,&iobject,objectset,ntrans,
 		  inotr,trab,&idesvar,orname,icoordinate,&inorm,
-		  &irand,&ishape); 
+		  &irand,&ishape,&ifeasd); 
 
 	}  // enddo loop idesvar
 
@@ -878,7 +878,7 @@ void objectivemain_se(double *co,ITG *nk,ITG *kon,ITG *ipkon,char *lakon,
 		  ne,cs,set,nset,istartset,iendset,ialset,
 		  jobnamec,output,temp,&iobject,objectset,ntrans,
 		  inotr,trab,&idesvar,orname,icoordinate,&inorm,
-		  &irand,&ishape); 
+		  &irand,&ishape,&ifeasd); 
 
 	}       
 		
@@ -895,7 +895,7 @@ void objectivemain_se(double *co,ITG *nk,ITG *kon,ITG *ipkon,char *lakon,
 	       
 	FORTRAN(disp_sen_dv,(&nodeset,istartset,iendset,ialset,&iobject,
 			     mi,nactdof,dgdu,vold,objectset,nactdofinv,
-			     &neq[1],g0));
+			     &neq[1],g0,nod1st,ne2d));
                        
 	/* Multiplication of dg/du with K^-1 */	    	      
 	    
@@ -938,7 +938,9 @@ void objectivemain_se(double *co,ITG *nk,ITG *kon,ITG *ipkon,char *lakon,
 	    
       SFREE(inum);
 	    
-    }else if(strcmp1(&objectset[m*405],"STRESS")==0){
+    }else if((strcmp1(&objectset[m*405],"MISESSTRESS")==0)||
+             (strcmp1(&objectset[m*405],"PS1STRESS")==0)||
+	     (strcmp1(&objectset[m*405],"PS3STRESS")==0)){
 	    
       /* OBJECTIVE: STRESS */
       
@@ -1052,7 +1054,7 @@ void objectivemain_se(double *co,ITG *nk,ITG *kon,ITG *ipkon,char *lakon,
 		 mortar,islavact,cdn,islavnode,nslavnode,ntie,clearini,
 		 islavsurf,ielprop,prop,energyini,energy,&kscale,
 		 &nener,orname,&network,neapar,nebpar,ipobody,ibody,xbody,
-		 nbody);
+		 nbody,physcon);
 	    
       *icmd=0;
 	    
@@ -1192,7 +1194,7 @@ void objectivemain_se(double *co,ITG *nk,ITG *kon,ITG *ipkon,char *lakon,
 		     mortar,islavact,cdn,islavnode,nslavnode,ntie,clearini,
 		     islavsurf,ielprop,prop,energyini,energy,&kscale,
 		     &nener,orname,&network,neapar,nebpar,ipobody,ibody,xbody,
-		     nbody);
+		     nbody,physcon);
 		
 	  *icmd=0;
 		
@@ -1215,7 +1217,7 @@ void objectivemain_se(double *co,ITG *nk,ITG *kon,ITG *ipkon,char *lakon,
 		  ne,cs,set,nset,istartset,iendset,ialset,
 		  jobnamec,output,temp,&iobject,objectset,ntrans,
 		  inotr,trab,&idesvar,orname,icoordinate,&inorm,
-		  &irand,&ishape); 
+		  &irand,&ishape,&ifeasd); 
 		
 	  SFREE(dstn);
 		
@@ -1295,12 +1297,13 @@ void objectivemain_se(double *co,ITG *nk,ITG *kon,ITG *ipkon,char *lakon,
 	prop1=prop;kscale1=kscale;iobject1=iobject;objectset1=objectset;
 	g01=g0;dgdx1=dgdx;nasym1=nasym;distmin1=distmin;idesvar1=idesvar;
 	dv1=dv;dstn1=dstn;dstx1=dstx;ialdesi1=ialdesi;ialnk1=ialnk;
-	dgdu1=dgdu;ialeneigh1=ialeneigh;ialnneigh1=ialnneigh;expks1=&expks;	      
-	stx1=stx;dispmin1=dispmin;ipos1=&ipos;istartnneigh1=istartnneigh;	      
+	dgdu1=dgdu;ialeneigh1=ialeneigh;ialnneigh1=ialnneigh;expks1=&expks;
+	stx1=stx;dispmin1=dispmin;ipos1=&ipos;istartnneigh1=istartnneigh;
 	istarteneigh1=istarteneigh;conew1=conew;nodedesired1=nodedesired;
 	nodedesi1=nodedesi;istartdesi1=istartdesi;xdesi1=xdesi;
 	nactdofred1=nactdofred;nactdofinv1=nactdofinv;mt1=&mt;
-	istartnk1=istartnk;ndesi1=ndesi;iponod2dto3d1=iponod2dto3d;
+	istartnk1=istartnk;ndesi1=ndesi;nod2nd3rd1=nod2nd3rd;
+	physcon1=physcon;
 
 	/* Variation of the coordinates of the designvariables */
 	      
@@ -1462,8 +1465,8 @@ void objectivemain_se(double *co,ITG *nk,ITG *kon,ITG *ipkon,char *lakon,
 
       RENEW(ialnk,ITG,istartnk[*nk]-1);
 		
-      /* storing the nodes of the neighboring elements of node nk 
-	 in field ialnneigh */
+      /* storing the design response nodes of the neighboring elements of 
+	 node nk in field ialnneigh */
 		
       NNEW(istartnneigh,ITG,*nk+1);
       NNEW(ialnneigh,ITG,20*(istartnk[*nk]-1));
@@ -1524,7 +1527,7 @@ void objectivemain_se(double *co,ITG *nk,ITG *kon,ITG *ipkon,char *lakon,
       *iout=2;
       *icmd=3;
 	    
-         resultsstr(co,nk,kon,ipkon,lakon,ne,v,stn,inum,stx,
+      resultsstr(co,nk,kon,ipkon,lakon,ne,v,stn,inum,stx,
 		 elcon,nelcon,rhcon,nrhcon,alcon,nalcon,alzero,ielmat,
 		 ielorien,norien,orab,ntmat_,t0,t1,ithermal,
 		 prestr,iprestr,filabl,eme,emn,een,iperturb,
@@ -1542,7 +1545,7 @@ void objectivemain_se(double *co,ITG *nk,ITG *kon,ITG *ipkon,char *lakon,
 		 mortar,islavact,cdn,islavnode,nslavnode,ntie,clearini,
 		 islavsurf,ielprop,prop,energyini,energy,&kscale,
 		 &nener,orname,&network,neapar,nebpar,ipobody,ibody,xbody,
-		 nbody);
+		 nbody,physcon);
 	    
       *icmd=0;
 	    
@@ -1553,17 +1556,18 @@ void objectivemain_se(double *co,ITG *nk,ITG *kon,ITG *ipkon,char *lakon,
 
       /* calculating the objective function */
 
-      nodeset=0;
+      /*      nodeset=0;
       for(i=0;i<*nset;i++){
 	if(strcmp1(&objectset[m*405+162]," ")==0) continue;
 	if(strcmp2(&objectset[m*405+162],&set[i*81],81)==0){
 	  nodeset=i+1;
 	  break;
 	}
-      }
-        FORTRAN(objective_peeq,(&nodeset,istartset,iendset,
+	}*/
+      FORTRAN(objective_peeq,(&nodeset,istartset,iendset,
 			      ialset,nk,&idesvar,&iobject,mi,g0,
-			      nobject,epn,objectset,&expks));
+			      nobject,epn,objectset,&expks,
+			      set,nset));
 
       /* reduce the size of the loops */
 	      
@@ -1633,13 +1637,13 @@ void objectivemain_se(double *co,ITG *nk,ITG *kon,ITG *ipkon,char *lakon,
       prop1=prop;kscale1=kscale;iobject1=iobject;objectset1=objectset;
       g01=g0;dgdx1=dgdx;nasym1=nasym;distmin1=distmin;idesvar1=idesvar;
       dv1=dv;depn1=depn;ialdesi1=ialdesi;ialnk1=ialnk;
-      dgdu1=dgdu;ialeneigh1=ialeneigh;ialnneigh1=ialnneigh;expks1=&expks;	      
+      dgdu1=dgdu;ialeneigh1=ialeneigh;ialnneigh1=ialnneigh;expks1=&expks;
       stx1=stx;dispmin1=dispmin;ipos1=&ipos;istartnneigh1=istartnneigh;	      
       istarteneigh1=istarteneigh;conew1=conew;nodedesired1=nodedesired;
       nodedesi1=nodedesi;istartdesi1=istartdesi;xdesi1=xdesi;
       nactdofred1=nactdofred;nactdofinv1=nactdofinv;mt1=&mt;
-      istartnk1=istartnk;ndesi1=ndesi;iponod2dto3d1=iponod2dto3d;
-      xstate1=xstate;
+      istartnk1=istartnk;ndesi1=ndesi;nod2nd3rd1=nod2nd3rd;
+      xstate1=xstate;physcon1=physcon;
 
       /* Variation of the coordinates of the designvariables */
 	      
@@ -1890,7 +1894,7 @@ void objectivemain_se(double *co,ITG *nk,ITG *kon,ITG *ipkon,char *lakon,
 		 mortar,islavact,cdn,islavnode,nslavnode,ntie,clearini,
 		 islavsurf,ielprop,prop,energyini,energy,&kscale,
 		 &nener,orname,&network,neapar,nebpar,ipobody,ibody,xbody,
-		 nbody);
+		 nbody,physcon);
 	    
       *icmd=0;
 	    
@@ -1979,12 +1983,13 @@ void objectivemain_se(double *co,ITG *nk,ITG *kon,ITG *ipkon,char *lakon,
       prop1=prop;kscale1=kscale;iobject1=iobject;objectset1=objectset;
       g01=g0;dgdx1=dgdx;nasym1=nasym;distmin1=distmin;idesvar1=idesvar;
       dv1=dv;dstn1=dstn;dstx1=dstx;ialdesi1=ialdesi;ialnk1=ialnk;
-      dgdu1=dgdu;ialeneigh1=ialeneigh;ialnneigh1=ialnneigh;expks1=&expks;	      
+      dgdu1=dgdu;ialeneigh1=ialeneigh;ialnneigh1=ialnneigh;expks1=&expks;
       stx1=stx;dispmin1=dispmin;ipos1=&ipos;istartnneigh1=istartnneigh;	      
       istarteneigh1=istarteneigh;conew1=conew;nodedesired1=nodedesired;
       nodedesi1=nodedesi;istartdesi1=istartdesi;xdesi1=xdesi;
       nactdofred1=nactdofred;nactdofinv1=nactdofinv;mt1=&mt;
-      istartnk1=istartnk;ndesi1=ndesi;iponod2dto3d1=iponod2dto3d;
+      istartnk1=istartnk;ndesi1=ndesi;nod2nd3rd1=nod2nd3rd;
+      physcon1=physcon;
 
       /* Variation of the coordinates of the designvariables */
 	      
@@ -2191,7 +2196,7 @@ void *objectivemt_shapeener_dx(ITG *i){
 				  ielprop1,prop1,distmin1,ndesi1,nodedesi1,
 				  nobject1,&g01[indexg0],&dgdx1[indexdgdx],
 				  &iobject1,sti1,xener1,istartdesi1,ialdesi1,
-				  xdesi1,&idesvar1));
+				  xdesi1,&idesvar1,physcon1));
 
   return NULL;
 }
@@ -2261,12 +2266,15 @@ void *stress_sen_dxmt(ITG *i){
   
   /* perturbation of the coordinates of the neighboring nodes of the design 
      variables
-     in case of an axisymmetric or plain strain (stress? shell?) model */
+     in case of an axisymmetric or plain stress/strain or shell model */
   
   nelem=ialdesi1[nea-1]-1;
-  if((strcmp1(&lakon1[nelem*8+6],"A")==0)||(strcmp1(&lakon1[nelem*8+6],"E")==0)){ 
-    node1=iponod2dto3d1[2*(node-1)];
-    node2=iponod2dto3d1[2*(node-1)+1];
+  if((strcmp1(&lakon1[nelem*8+6],"A")==0)||(strcmp1(&lakon1[nelem*8+6],"E")==0)||
+     (strcmp1(&lakon1[nelem*8+6],"S")==0)||(strcmp1(&lakon1[nelem*8+6],"L")==0)){ 
+    //    node1=nod2nd3rd1[2*(node-1)];
+    //    node2=nod2nd3rd1[2*(node-1)+1];
+    node1=node+1;
+    node2=node+2;
   
     for(j=0;j<3;j++){ 
       conew1[(node1-1)*3+j+3**nk1**i]=co1[(node1-1)*3+j]+xdesi1[(idesvar-1)*3+j];
@@ -2287,7 +2295,7 @@ void *stress_sen_dxmt(ITG *i){
 		&nea,&neb,nasym1,distmin1,&idesvar,&dstx1[6*mi1[0]**ne1**i],
 		ialdesi1,
 		ialeneigh1,&neaneigh,&nebneigh,ialnneigh1,&naneigh,&nbneigh,
-		stn1,expks1,ndesi1);
+		stn1,expks1,ndesi1,physcon1);
   
   return NULL;
 }
@@ -2326,18 +2334,19 @@ void *stress_sen_dvmt(ITG *i){
 
   dv1[(node-1)**mt1+idir+*mt1**nk1**i]+=dispmin1;	       
 
-  /* perturbation of the coordinates of the neighboring nodes of the design variables
-     in case of an axisymmetric or plain strain (plane stress? shell?) model */
+  /* perturbation of the displacements of the neighboring nodes of the design variables
+     in case of an axisymmetric or plain stress/strain or shell model */
   
-  nelem=ialnk1[nea-1]-1;
-  if((strcmp1(&lakon1[nelem*8+6],"A")==0)||(strcmp1(&lakon1[nelem*8+6],"E")==0)){ 
-    node1=iponod2dto3d1[2*(node-1)];
-    node2=iponod2dto3d1[2*(node-1)+1];
+  /*  nelem=ialnk1[nea-1]-1;
+    if((strcmp1(&lakon1[nelem*8+6],"A")==0)||(strcmp1(&lakon1[nelem*8+6],"E")==0)||
+     (strcmp1(&lakon1[nelem*8+6],"S")==0)||(strcmp1(&lakon1[nelem*8+6],"L")==0)){ 
+    node1=node+1;
+    node2=node+2;
   
     dv1[(node1-1)**mt1+idir+*mt1**nk1**i]+=dispmin1;
     dv1[(node2-1)**mt1+idir+*mt1**nk1**i]+=dispmin1;
 	
-  } 
+    } */
     
   stress_sen_dv(co1,nk1,kon1,ipkon1,lakon1,ne1,&dstn1[6**nk1**i],
 		elcon1,nelcon1,rhcon1,nrhcon1,alcon1,nalcon1,alzero1,ielmat1,
@@ -2351,7 +2360,7 @@ void *stress_sen_dvmt(ITG *i){
 		nasym1,distmin1,&dstx1[6*mi1[0]**ne1**i],ialnk1,dgdu1,
 		ialeneigh1,
 		&neaneigh,&nebneigh,ialnneigh1,&naneigh,&nbneigh,stn1,expks1,
-		objectset1,&idof,&node,&idir,vold1,&dispmin1);
+		objectset1,&idof,&node,&idir,vold1,&dispmin1,physcon1);
  
   return NULL;
 }
@@ -2393,12 +2402,15 @@ void *peeq_sen_dxmt(ITG *i){
   
   /* perturbation of the coordinates of the neighboring nodes of the design 
      variables
-     in case of an axisymmetric or plain strain (stress? shell?) model */
+     in case of an axisymmetric or plain stress/strain or shell model */
   
   nelem=ialdesi1[nea-1]-1;
-  if((strcmp1(&lakon1[nelem*8+6],"A")==0)||(strcmp1(&lakon1[nelem*8+6],"E")==0)){ 
-    node1=iponod2dto3d1[2*(node-1)];
-    node2=iponod2dto3d1[2*(node-1)+1];
+  if((strcmp1(&lakon1[nelem*8+6],"A")==0)||(strcmp1(&lakon1[nelem*8+6],"E")==0)||
+     (strcmp1(&lakon1[nelem*8+6],"S")==0)||(strcmp1(&lakon1[nelem*8+6],"L")==0)){ 
+    //    node1=nod2nd3rd1[2*(node-1)];
+    //    node2=nod2nd3rd1[2*(node-1)+1];
+    node1=node+1;
+    node2=node+2;
   
     for(j=0;j<3;j++){ 
       conew1[(node1-1)*3+j+3**nk1**i]=co1[(node1-1)*3+j]+xdesi1[(idesvar-1)*3+j];
@@ -2407,20 +2419,20 @@ void *peeq_sen_dxmt(ITG *i){
   } 
 
   peeq_sen_dx(&conew1[3**nk1**i],nk1,kon1,ipkon1,lakon1,ne1,
-		&depn1[*nk1**i],
-		elcon1,nelcon1,rhcon1,nrhcon1,alcon1,nalcon1,alzero1,ielmat1,
-		ielorien1,norien1,orab1,ntmat1_,t01,t11,ithermal1,prestr1,
-		iprestr1,filabl1,iperturb1,vold1,nmethod1,dtime1,time1,
-		ttime1,plicon1,nplicon1,plkcon1,nplkcon1,xstateini1,
-		&dxstate1[*nstate1_*mi1[0]**ne1**i],
-		npmat1_,matname1,mi1,ielas1,ncmat1_,nstate1_,stiini1,vini1,
-		emeini1,enerini1,istep1,iinc1,springarea1,reltime1,ne01,
-		thicke1,pslavsurf1,pmastsurf1,mortar1,clearini1,ielprop1,
-		prop1,&kscale1,&iobject1,objectset1,g01,dgdx1,
-		&nea,&neb,nasym1,distmin1,&idesvar,stx1,
-		ialdesi1,
-		ialeneigh1,&neaneigh,&nebneigh,ialnneigh1,&naneigh,&nbneigh,
-		epn1,expks1,ndesi1);
+	      &depn1[*nk1**i],
+	      elcon1,nelcon1,rhcon1,nrhcon1,alcon1,nalcon1,alzero1,ielmat1,
+	      ielorien1,norien1,orab1,ntmat1_,t01,t11,ithermal1,prestr1,
+	      iprestr1,filabl1,iperturb1,vold1,nmethod1,dtime1,time1,
+	      ttime1,plicon1,nplicon1,plkcon1,nplkcon1,xstateini1,
+	      &dxstate1[*nstate1_*mi1[0]**ne1**i],
+	      npmat1_,matname1,mi1,ielas1,ncmat1_,nstate1_,stiini1,vini1,
+	      emeini1,enerini1,istep1,iinc1,springarea1,reltime1,ne01,
+	      thicke1,pslavsurf1,pmastsurf1,mortar1,clearini1,ielprop1,
+	      prop1,&kscale1,&iobject1,objectset1,g01,dgdx1,
+	      &nea,&neb,nasym1,distmin1,&idesvar,stx1,
+	      ialdesi1,
+	      ialeneigh1,&neaneigh,&nebneigh,ialnneigh1,&naneigh,&nbneigh,
+	      epn1,expks1,ndesi1,physcon1);
   
   return NULL;
 }
@@ -2459,32 +2471,33 @@ void *peeq_sen_dvmt(ITG *i){
 
   dv1[(node-1)**mt1+idir+*mt1**nk1**i]+=dispmin1;	       
 
-  /* perturbation of the coordinates of the neighboring nodes of the design variables
-     in case of an axisymmetric or plain strain (plane stress? shell?) model */
+  /* perturbation of the displacements of the neighboring nodes of the design variables
+     in case of an axisymmetric or plain stress/strain or shell model */
   
-  nelem=ialnk1[nea-1]-1;
-  if((strcmp1(&lakon1[nelem*8+6],"A")==0)||(strcmp1(&lakon1[nelem*8+6],"E")==0)){ 
-    node1=iponod2dto3d1[2*(node-1)];
-    node2=iponod2dto3d1[2*(node-1)+1];
+  /*  nelem=ialnk1[nea-1]-1;
+    if((strcmp1(&lakon1[nelem*8+6],"A")==0)||(strcmp1(&lakon1[nelem*8+6],"E")==0)||
+     (strcmp1(&lakon1[nelem*8+6],"S")==0)||(strcmp1(&lakon1[nelem*8+6],"L")==0)){ 
+    node1=node+1;
+    node2=node+2;
   
     dv1[(node1-1)**mt1+idir+*mt1**nk1**i]+=dispmin1;
     dv1[(node2-1)**mt1+idir+*mt1**nk1**i]+=dispmin1;
 	
-  } 
+    } */
     
   peeq_sen_dv(co1,nk1,kon1,ipkon1,lakon1,ne1,&depn1[*nk1**i],
-		elcon1,nelcon1,rhcon1,nrhcon1,alcon1,nalcon1,alzero1,ielmat1,
-		ielorien1,norien1,orab1,ntmat1_,t01,t11,ithermal1,prestr1,
-		iprestr1,filabl1,iperturb1,&dv1[*mt1**nk1**i],nmethod1,dtime1,
-		time1,ttime1,plicon1,nplicon1,plkcon1,nplkcon1,xstateini1,
-		&dxstate1[*nstate1_*mi1[0]**ne1**i],
-	        npmat1_,matname1,mi1,ielas1,ncmat1_,nstate1_,
-		stiini1,vini1,emeini1,enerini1,istep1,iinc1,springarea1,
-		reltime1,ne01,thicke1,pslavsurf1,pmastsurf1,mortar1,
-		clearini1,ielprop1,prop1,&kscale1,&iobject1,g01,&nea,&neb,
-		nasym1,distmin1,stx1,ialnk1,dgdu1,ialeneigh1,
-		&neaneigh,&nebneigh,ialnneigh1,&naneigh,&nbneigh,epn1,expks1,
-		objectset1,&idof,&node,&idir,vold1,&dispmin1);
+	      elcon1,nelcon1,rhcon1,nrhcon1,alcon1,nalcon1,alzero1,ielmat1,
+	      ielorien1,norien1,orab1,ntmat1_,t01,t11,ithermal1,prestr1,
+	      iprestr1,filabl1,iperturb1,&dv1[*mt1**nk1**i],nmethod1,dtime1,
+	      time1,ttime1,plicon1,nplicon1,plkcon1,nplkcon1,xstateini1,
+	      &dxstate1[*nstate1_*mi1[0]**ne1**i],
+	      npmat1_,matname1,mi1,ielas1,ncmat1_,nstate1_,
+	      stiini1,vini1,emeini1,enerini1,istep1,iinc1,springarea1,
+	      reltime1,ne01,thicke1,pslavsurf1,pmastsurf1,mortar1,
+	      clearini1,ielprop1,prop1,&kscale1,&iobject1,g01,&nea,&neb,
+	      nasym1,distmin1,stx1,ialnk1,dgdu1,ialeneigh1,
+	      &neaneigh,&nebneigh,ialnneigh1,&naneigh,&nbneigh,epn1,expks1,
+	      objectset1,&idof,&node,&idir,vold1,&dispmin1,physcon1);
  
   return NULL;
 }
