@@ -1,5 +1,5 @@
 /*     CalculiX - A 3-dimensional finite element program                 */
-/*              Copyright (C) 1998-2022 Guido Dhondt                     */
+/*              Copyright (C) 1998-2023 Guido Dhondt                     */
 
 /*     This program is free software; you can redistribute it and/or     */
 /*     modify it under the terms of the GNU General Public License as    */
@@ -90,7 +90,8 @@ void radflowload(ITG *itg,ITG *ieg,ITG *ntg,ITG *ntr,double *adrad,
 
   ITG nhrs=1,info=0,i,j,iin=0,icntrl,icutb=0,iin_abs=0,mt=mi[1]+1,im,
     symmetryflag=2,inputformat=1,node,ichannel,*ithread=NULL,iplausi,
-    *itreated=NULL,*istack=NULL,ndata,*jumpup=NULL,*jumpdo=NULL;
+    *itreated=NULL,*istack=NULL,ndata,*jumpup=NULL,*jumpdo=NULL,
+    *istackb=NULL,*ixnode=NULL,*iyload=NULL;
 
   static ITG ifactorization=0;
 
@@ -166,12 +167,15 @@ void radflowload(ITG *itg,ITG *ieg,ITG *ntg,ITG *ntr,double *adrad,
 	  ndata=100;
 	  NNEW(itreated,ITG,*nflow);
 	  NNEW(istack,ITG,2**ntg);
+	  NNEW(istackb,ITG,2**ntg);
 	  NNEW(sfr,double,ndata**nflow);
 	  NNEW(hfr,double,ndata**nflow);
 	  NNEW(sba,double,ndata**nflow);
 	  NNEW(hba,double,ndata**nflow);
 	  NNEW(jumpup,ITG,*nflow);
 	  NNEW(jumpdo,ITG,*nflow);
+	  NNEW(ixnode,ITG,*nload);
+	  NNEW(iyload,ITG,*nload);
 	  FORTRAN(initialchannel,(itg,ieg,ntg,lakon,v,ipkon,kon,nflow,
 				  ikboun,nboun,prop,ielprop,ndirboun,
 				  nodeboun,xbounact,ielmat,ntmat_,shcon,nshcon,
@@ -179,8 +183,12 @@ void radflowload(ITG *itg,ITG *ieg,ITG *ntg,ITG *ntr,double *adrad,
 				  xbodyact,co,nbody,network,vold,set,
 				  istep,iit,mi,ineighe,ilboun,ttime,time,
 				  itreated,iponoel,inoel,istack,sfr,hfr,
-				  sba,hba,&ndata,jumpup,jumpdo));
-	  SFREE(itreated);SFREE(istack);SFREE(hfr);SFREE(hba);
+				  sba,hba,&ndata,jumpup,jumpdo,istackb,
+				  nelemload,ixnode,iyload,nload,sideload,
+				  xloadact,cocon,ncocon,iinc,nforc,ikforc,
+				  ilforc,xforcact));
+	  SFREE(itreated);SFREE(istack);SFREE(hfr);SFREE(hba);SFREE(istackb);
+	  SFREE(ixnode);SFREE(iyload);
 	  break;
 	}
 
