@@ -1,6 +1,6 @@
 !     
 !     CalculiX - A 3-dimensional finite element program
-!     Copyright (C) 1998-2022 Guido Dhondt
+!     Copyright (C) 1998-2023 Guido Dhondt
 !     
 !     This program is free software; you can redistribute it and/or
 !     modify it under the terms of the GNU General Public License as
@@ -119,7 +119,7 @@
      &        FORM='UNFORMATTED',err=151)
       endif
 !     
-      version='Version 2.20'
+      version='Version 2.21'
       write(15) version
 !     
       write(15)istepnew
@@ -451,12 +451,16 @@
       write(15)(sti(i),i=1,6*mi(1)*ne)
       write(15)(eme(i),i=1,6*mi(1)*ne)
       if(nener.eq.1) then
-         write(15)(ener(i),i=1,mi(1)*ne)
+        if(mortar.ne.1) then
+          write(15)(ener(i),i=1,2*mi(1)*(ne+nslavs))
+        else
+          write(15)(ener(i),i=1,2*mi(1)*ne)
+        endif
       endif
       if(nstate_.gt.0)then
-         if(mortar.eq.0) then
+         if(mortar.ne.1) then
             write(15)(xstate(i),i=1,nstate_*mi(1)*(ne+nslavs))
-         elseif(mortar.eq.1) then
+         else
             write(15)(xstate(i),i=1,nstate_*mi(1)*(ne+nintpoint))
          endif
       endif
