@@ -1,6 +1,6 @@
 !
 !     CalculiX - A 3-dimensional finite element program
-!              Copyright (C) 1998-2022 Guido Dhondt
+!              Copyright (C) 1998-2023 Guido Dhondt
 !
 !     This program is free software; you can redistribute it and/or
 !     modify it under the terms of the GNU General Public License as
@@ -39,7 +39,7 @@
       real*8 xl(3,19),al(3),vl(0:mi(2),19),conductance,
      &  pl(3,19),xn(3),alpha,beta,
      &  elcon(0:ncmat_,ntmat_,*),pproj(3),clear,
-     &  xi,et,elconloc(21),plconloc(802),xk,xiso(20),yiso(20),
+     &  xi,et,elconloc(*),plconloc(802),xk,xiso(20),yiso(20),
      &  plicon(0:2*npmat_,ntmat_,*),coords(3),
      &  springarea(2),overlap,clearini(3,9,*),
      &  reltime,weight,xsj2m(3),xs2m(3,7),shp2m(7,9),
@@ -83,16 +83,12 @@
       weight=pslavsurf(3,igauss)
 !
       iflag=1
-c      if(nopes.eq.9) then
-c          call shape9q(xi,et,pl(1,nopem+1),xsj2s,xs2s,shp2s,iflag)
       if(nopes.eq.8) then
           call shape8q(xi,et,pl(1,nopem+1),xsj2s,xs2s,shp2s,iflag)
       elseif(nopes.eq.4) then
           call shape4q(xi,et,pl(1,nopem+1),xsj2s,xs2s,shp2s,iflag)
       elseif(nopes.eq.6) then
           call shape6tri(xi,et,pl(1,nopem+1),xsj2s,xs2s,shp2s,iflag)
-c      elseif(nopes.eq.7) then
-c          call shape7tri(xi,et,pl(1,nopem+1),xsj2s,xs2s,shp2s,iflag)
       else
           call shape3tri(xi,et,pl(1,nopem+1),xsj2s,xs2s,shp2s,iflag)
       endif
@@ -118,16 +114,12 @@ c          call shape7tri(xi,et,pl(1,nopem+1),xsj2s,xs2s,shp2s,iflag)
 !     determining the jacobian vector on the surface 
 !
       iflag=2
-c      if(nopem.eq.9) then
-c         call shape9q(xi,et,pl,xsj2m,xs2m,shp2m,iflag)
       if(nopem.eq.8) then
          call shape8q(xi,et,pl,xsj2m,xs2m,shp2m,iflag)
       elseif(nopem.eq.4) then
          call shape4q(xi,et,pl,xsj2m,xs2m,shp2m,iflag)
       elseif(nopem.eq.6) then
          call shape6tri(xi,et,pl,xsj2m,xs2m,shp2m,iflag)
-c      elseif(nopem.eq.7) then
-c         call shape7tri(xi,et,pl,xsj2m,xs2m,shp2m,iflag)
       else
          call shape3tri(xi,et,pl,xsj2m,xs2m,shp2m,iflag)
       endif
