@@ -1,6 +1,6 @@
 !
 !     CalculiX - A 3-dimensional finite element program
-!              Copyright (C) 1998-2022 Guido Dhondt
+!              Copyright (C) 1998-2023 Guido Dhondt
 !
 !     This program is free software; you can redistribute it and/or
 !     modify it under the terms of the GNU General Public License as
@@ -37,7 +37,7 @@
      &  al(3),s(60,60),voldl(0:mi(2),19),pl(3,19),xn(3),
      &  c1,c3,alpha,beta,elcon(0:ncmat_,ntmat_,*),xm(3),
      &  fpu(3,3),xi,et,fnl(3),
-     &  xs2(3,7),t1l,elconloc(21),plconloc(82),xk,stickslope,
+     &  xs2(3,7),t1l,elconloc(*),plconloc(82),xk,stickslope,
      &  xiso(20),yiso(20),plicon(0:2*npmat_,ntmat_,*),
      &  springarea(2),t(3),tu(3,3),overlap,pres,dpresdoverlap,
      &  xstate(nstate_,mi(1),*),xstateini(nstate_,mi(1),*),
