@@ -1,6 +1,6 @@
 !     
 !     CalculiX - A 3-dimensional finite element program
-!     Copyright (C) 1998-2022 Guido Dhondt
+!     Copyright (C) 1998-2023 Guido Dhondt
 !     
 !     This program is free software; you can redistribute it and/or
 !     modify it under the terms of the GNU General Public License as
@@ -49,10 +49,15 @@
 !     
       do i=1,nnfront
 !     
-!     target number of nodes in the circle of influence
+!       target number of nodes in the circle of influence
 !     
         nmax=max(1,int((iendfront(i)-istartfront(i)+1)/1.1d0))
         if(nmax.le.2) cycle
+!     
+!       next line introduced on 27th of Nov 2022 to limit the radius 
+!       of influence     
+!     
+        nmax=min(nmax,5)
 !     
         istart=istartfront(i)
         iend=iendfront(i)
