@@ -1,6 +1,6 @@
 !
 !     CalculiX - A 3-dimensional finite element program
-!              Copyright (C) 1998-2022 Guido Dhondt
+!              Copyright (C) 1998-2023 Guido Dhondt
 !
 !     This program is free software; you can redistribute it and/or
 !     modify it under the terms of the GNU General Public License as
@@ -17,9 +17,10 @@
 !     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 !
       subroutine umat_ideal_gas(amat,iel,iint,kode,elconloc,emec,emec0,
-     &        beta,xokl,voj,xkl,vj,ithermal,t1l,dtime,time,ttime,
-     &        icmd,ielas,mi,
-     &        nstate_,xstateini,xstate,stre,stiff,iorien,pgauss,orab)
+     &     beta,xokl,voj,xkl,vj,ithermal,t1l,dtime,time,ttime,
+     &     icmd,ielas,mi,
+     &     nstate_,xstateini,xstate,stre,stiff,iorien,pgauss,orab,
+     &     physcon)
 !
 !     calculates stiffness and stresses for an ideal gas
 !     For this material there is just one material constant equal to
@@ -30,7 +31,8 @@
 !     material has to start with IDEAL_GAS, e.g. IDEAL_GAS_AIR or
 !     IDEAL_GAS_NITROGEN etc.
 !
-!     This routine should only be used with nlgeom=yes
+!     This routine should only be used with nlgeom=yes and
+!     *PHYSICAL CONSTANTS must be used to define absolute zero temperature
 !
 !     icmd=3: calculates stress at mechanical strain
 !     else: calculates stress at mechanical strain and the stiffness
@@ -46,8 +48,8 @@
 !                        under *USER MATERIAL): can be used for materials
 !                        with varying number of constants
 !
-!     elconloc(21)       user defined constants defined by the keyword
-!                        card *USER MATERIAL (max. 21, actual # =
+!     elconloc(*)        user defined constants defined by the keyword
+!                        card *USER MATERIAL (actual # =
 !                        -kode-100), interpolated for the
 !                        actual temperature t1l
 !
@@ -101,6 +103,7 @@
 !                        tensors with skl(3,3). skl is  determined by calling
 !                        the subroutine transformatrix: 
 !                        call transformatrix(orab(1,iorien),pgauss,skl)
+!     physcon(1)         absolute zero (for the temperature)
 !
 !
 !     OUTPUT:
@@ -131,7 +134,7 @@
       real*8 elconloc(*),stiff(21),emec(6),emec0(6),beta(6),stre(6),
      &  vj,t1l,dtime,xkl(3,3),xokl(3,3),voj,pgauss(3),orab(7,*),
      &  time,ttime,xstate(nstate_,mi(1),*),xstateini(nstate_,mi(1),*),
-     &  rho0r,c(3,3),cinv(3,3),v3,didc(3,3)
+     &  rho0r,c(3,3),cinv(3,3),v3,didc(3,3),physcon(*)
 !
       kk=(/1,1,1,1,1,1,2,2,2,2,2,2,1,1,3,3,2,2,3,3,3,3,3,3,
      &  1,1,1,2,2,2,1,2,3,3,1,2,1,2,1,2,1,1,1,3,2,2,1,3,3,3,1,3,
@@ -140,8 +143,8 @@
 !
       rho0r=elconloc(1)
 !
-!     calculation of the Green deformation tensor for the total
-!     strain and the thermal strain
+!     calculation of the Green deformation tensor from the Lagrange
+!     strain
 !     
       do i=1,3
          c(i,i)=emec(i)*2.d0+1.d0
@@ -167,41 +170,47 @@
       cinv(2,1)=cinv(1,2)
       cinv(3,1)=cinv(1,3)
       cinv(3,2)=cinv(2,3)
+c      write(*,*) 'cinv umat_ideal_gas1 ',cinv(1,1),cinv(2,2),cinv(3,3)
+c      write(*,*) 'cinv umat_ideal_gas2 ',cinv(1,2),cinv(1,3),cinv(2,3)
 !
 !     changing the meaning of v3
 !
-      v3=v3*rho0r
+      v3=v3*rho0r*(t1l-physcon(1))
 !
-!     stress at mechanical strain
+!     stress from the  mechanical strain: 
+!     sigma=-rho_0*r*T*C^{-1}
+!     
+      stre(1)=-v3*cinv(1,1)
+      stre(2)=-v3*cinv(2,2)
+      stre(3)=-v3*cinv(3,3)
+      stre(4)=-v3*cinv(1,2)
+      stre(5)=-v3*cinv(1,3)
+      stre(6)=-v3*cinv(2,3)
+c      write(*,*) 'umat_ideal_gas ',stre(1),stre(2),stre(4)
+!     
+!     tangent=-2*rho_0*r*T*d(C^{-1})/dC
 !     
-      stre(1)=v3*cinv(1,1)
-      stre(2)=v3*cinv(2,2)
-      stre(3)=v3*cinv(3,3)
-      stre(4)=v3*cinv(1,2)
-      stre(5)=v3*cinv(1,3)
-      stre(6)=v3*cinv(2,3)
-!
-!     tangent
-!
       if(icmd.ne.3) then
+!     
+        nt=0
+        do i=1,21
+          k=kk(nt+1)
+          l=kk(nt+2)
+          m=kk(nt+3)
+          n=kk(nt+4)
+          nt=nt+4
+! 
+!         in my opinion, the "-" before v3 in the next line should be
+!         deleted. However, without "-" divergence occurs;
+!         
 !
-!
-!        second derivative of the c-invariants w.r.t. c(k,l) 
-!        and c(m,n)
-!
-         if(icmd.ne.3) then
-            nt=0
-            do i=1,21
-               k=kk(nt+1)
-               l=kk(nt+2)
-               m=kk(nt+3)
-               n=kk(nt+4)
-               nt=nt+4
-               stiff(i)=v3*(cinv(m,n)*cinv(k,l)-
-     &            (cinv(k,m)*cinv(n,l)+cinv(k,n)*cinv(m,l))/2.d0)
-            enddo
-         endif
+          stiff(i)=-v3*
+     &         (cinv(k,m)*cinv(n,l)+cinv(k,n)*cinv(m,l))
+c          stiff(i)=-v3*2.d0*
+c     &         (cinv(k,m)*cinv(n,l))
+        enddo
+c      write(*,*) 'umat_ideal_gas: ',iel,iint,stiff(1),stiff(21)
       endif
-!
+!     
       return
       end
